import React, { useEffect, useState } from 'react'
import { Button, ButtonProps } from '../Button'
import './index.scss'

export interface CardProps {
	title: string
	imageUrl: string | File
	text?: string
	buttons: ButtonProps[]
}

export const Card: React.FC<CardProps> = ({ title, imageUrl, text, buttons }) => {
	const [imageSrc, setImageSrc] = useState<string>()

	useEffect(() => {
		if (imageUrl instanceof File) {
			const reader = new FileReader()
			reader.onloadend = () => {
				setImageSrc(reader.result as string)
			}
			reader.readAsDataURL(imageUrl)
		}
	}, [imageUrl])

	return (
		<div className='card-container'>
			<div className='card-top'>
				<p className='card-title'>{title}</p>
				<img
					className='card-image-url'
					src={imageUrl instanceof File ? imageSrc : imageUrl}
					alt='Module Image'
				/>
			</div>
			<div className='card-bottom'>
				<div className='card-buttons'>
					{buttons?.map((b, index) => (
						<Button key={index} variant='filled' color={b.color} size={b.size} onClick={b.onClick}>
							{b.children}
						</Button>
					))}
				</div>
				{text && <div className='card-text'>{text}</div>}
			</div>
		</div>
	)
}
