import React, { useState, useEffect } from 'react'
import Slide, { SlideProps } from './Slide'
import './index.scss'

const Carousel: React.FC<{ slides: SlideProps[] }> = ({ slides }) => {
	const [currentSlide, setCurrentSlide] = useState(0)

	const updateSlide = (index: number) => {
		if (index < 0) {
			return
		} else if (index >= slides.length) {
			index = 0
		}
		setCurrentSlide(index)
	}

	useEffect(() => {
		const interval = setTimeout(() => {
			updateSlide(currentSlide + 1)
		}, 7000)

		return () => clearInterval(interval)
	}, [currentSlide])

	return (
		<div className='carousel-container'>
			<div
				className='slide-container'
				style={{
					transform: `translate(${currentSlide * -(100 / slides.length)}%)`,
					width: `${slides.length * 100}%`
				}}
			>
				{slides.map((slide, index) => (
					<Slide
						key={index}
						title={slide.title}
						text={slide.text}
						image={slide.image}
						variant={slide.variant}
					/>
				))}
			</div>
			<div
				className={`carousel-button-prev ${currentSlide === 0 && 'disabled'}`}
				onClick={() => updateSlide(currentSlide - 1)}
			></div>
			<div
				className={`carousel-button-next ${currentSlide === slides.length - 1 && 'disabled'}`}
				onClick={() => updateSlide(currentSlide + 1)}
			></div>
			<div className='carousel-pagination'>
				{slides.map((_, index) => (
					<div
						key={index}
						className={`carousel-pagination-bullet ${currentSlide === index && 'active'}`}
						onClick={() => updateSlide(index)}
					></div>
				))}
			</div>
		</div>
	)
}

export default Carousel
