import React from 'react'
import { Button } from '../Button'
import { useModal } from '../../providers/Modal/ModalProvider'
import './index.scss'
import DefaultModal from '../DefaultModal'

export interface ConfirmationProps {
	title: string
	description: string
	handleConfirm: () => void
}

const Confirmation: React.FC<ConfirmationProps> = ({ title, description, handleConfirm }) => {
	const { setVisibility } = useModal()

	return (
		<DefaultModal
			title={title}
			content={<p className='confirmation-text'>{description}</p>}
			footer={
				<>
					<div className='confirmation-button'>
						<Button
							variant='outlined'
							color='secondary'
							size='big'
							onClick={() => {
								setVisibility?.(false)
							}}
						>
							<div className='modal-button-text'>Não</div>
						</Button>
						<Button
							variant='filled'
							color='primary'
							size='big'
							onClick={() => {
								handleConfirm()
								setVisibility?.(false)
							}}
						>
							<div className='modal-button-text'>Sim</div>
						</Button>
					</div>
				</>
			}
		/>
	)
}

export default Confirmation
