import './index.scss'
import React, { ReactNode } from 'react'
import { useSortable } from '@dnd-kit/sortable'
import { CSS } from '@dnd-kit/utilities'
import { ReactComponent as DragHandleIcon } from '../../assets/icons/drag-handle.svg'
import IconButton from '../IconButton'

export interface GenericWithId {
	id: number
}

export interface DraggableItemProps<T extends GenericWithId> {
	item: T
	render: (item: T) => ReactNode
}

function DragglableItem<T extends GenericWithId>({ item, render }: DraggableItemProps<T>) {
	const { attributes, listeners, setNodeRef, transform, transition } = useSortable({
		id: item.id,
		animateLayoutChanges: () => false,
		transition: {
			duration: 500,
			easing: 'cubic-bezier(0.165, 0.84, 0.44, 1)'
		}
	})

	const style = {
		transition,
		transform: CSS.Transform.toString(transform)
	}

	return (
		<div style={style} className='draggable-item-container'>
			<div ref={setNodeRef} {...attributes} {...listeners} className='draggable-trigger-area'>
				<IconButton helperLabel='Mover'>
					<DragHandleIcon className='draggable-trigger-area-icon' />
				</IconButton>
			</div>

			{render(item)}
		</div>
	)
}

export default DragglableItem
