import './index.scss'
import React, { ReactNode } from 'react'
import {
	DndContext,
	DragEndEvent,
	Modifier,
	PointerSensor,
	closestCorners,
	useSensor
} from '@dnd-kit/core'
import { SortableContext, horizontalListSortingStrategy } from '@dnd-kit/sortable'
import DragglableItem, { GenericWithId } from '../DraggableItem'

export interface DraggableSliderProps<T extends GenericWithId> {
	handleDragEnd?: (event: DragEndEvent) => void
	items: T[]
	renderItem: (item: T) => ReactNode
}

function DraggableSlider<T extends GenericWithId>({
	handleDragEnd,
	items,
	renderItem
}: DraggableSliderProps<T>) {
	const restrictYMoves: Modifier = (args) => {
		const { transform } = args
		return {
			...transform,
			y: 0
		}
	}

	return (
		<DndContext
			sensors={[useSensor(PointerSensor)]}
			collisionDetection={closestCorners}
			onDragEnd={handleDragEnd}
			modifiers={[restrictYMoves]}
		>
			<div className='draggable-slider-container'>
				<SortableContext items={items} strategy={horizontalListSortingStrategy}>
					{items.map((i, index) => (
						<DragglableItem key={index} item={i} render={renderItem} />
					))}
				</SortableContext>
			</div>
		</DndContext>
	)
}

export default DraggableSlider
