import './index.scss'
import DefaultModal from '../DefaultModal'
import { Button } from '../Button'
import React, { useState } from 'react'
import { ReactComponent as Sad } from '../../assets/icons/sad.svg'
import { ReactComponent as Smile } from '../../assets/icons/smile.svg'
import { Loader } from '../Loader'

export interface FeedbackProps {
	onClickCancel: () => void
	onClickConfirmar: (stars: number) => void
	isPending: boolean
}

const Feedback: React.FC<FeedbackProps> = ({ isPending, onClickCancel, onClickConfirmar }) => {
	const [rating, setRating] = useState<number>(0)
	const [isDisabled, setDisabled] = useState<boolean>(true)

	const handleStarClick = (value: number) => {
		const oldValue = rating
		if (value !== 0 && value !== oldValue) {
			setRating(value)
			setDisabled(false)
			return
		}
		setRating(0)
		setDisabled(true)
	}

	return (
		<DefaultModal
			title='Avaliação do Curso'
			content={
				<div className='feedback-middle'>
					<p className='feedback-title'>Obrigado!</p>
					<p className='feedback-subtitle'>Avalie o curso abaixo:</p>
					<div className='feedback-stars'>
						<span className='feedback-stars-emotion'>
							<Sad />
						</span>
						{[1, 2, 3, 4, 5].map((num) => (
							<span
								key={num}
								onClick={() => handleStarClick(num)}
								className={`feedback-star ${num <= rating ? 'selected' : ''}`}
							>
								★
							</span>
						))}
						<span className='feedback-stars-emotion'>
							<Smile />
						</span>
					</div>
				</div>
			}
			footer={
				<>
					<Button
						variant='outlined'
						color='black'
						onClick={() => {
							onClickCancel()
						}}
					>
						<div className='modal-button-text'>Cancelar</div>
					</Button>
					<Button
						variant='filled'
						color='primary'
						disabled={isDisabled || isPending}
						onClick={() => {
							onClickConfirmar(rating)
						}}
					>
						<div className='modal-button-text'> {isPending ? <Loader /> : 'Enviar'}</div>
					</Button>
				</>
			}
		/>
	)
}

export default Feedback
