import React from 'react'
import './index.scss'
import { ReactComponent as DecolaLogo } from '../../assets/images/decola-small-logo.svg'
import { ReactComponent as AccountIcon } from '../../assets/icons/account-icon.svg'
import { Button } from '../Button'
import { useAuth } from '../../providers/Auth/AuthProvider'
import { UserRole } from '../../dtos/UserDto'
import { useNavigation } from '../../providers/Navigation/NavigationProvider'

const Header: React.FC = () => {
	const { logout, user, isLogged } = useAuth()
	const { navigateHome, navigateCourses, navigateAdminDashboard, navigateLogin } = useNavigation()

	return (
		<header className='header'>
			<div className='header-main'>
				<div className='header-content'>
					<div className='header-logo'>
						<DecolaLogo onClick={() => navigateHome?.()} />
					</div>
					<nav>
						<ul>
							<li>
								<p className='header-link' onClick={() => navigateHome?.()}>
									Home
								</p>
							</li>
							{user && user.role === UserRole.COLLABORATOR && (
								<li>
									<p className='header-link' onClick={() => navigateCourses?.()}>
										Cursos
									</p>
								</li>
							)}
							{user && user.role === UserRole.ADMIN && (
								<li>
									<p className='header-link' onClick={() => navigateAdminDashboard?.()}>
										Administração
									</p>
								</li>
							)}
						</ul>
					</nav>
				</div>
				<div className='header-button'>
					{isLogged?.() ? (
						<Button onClick={() => logout?.()}>
							<div className='account-button-content'>
								<AccountIcon /> Conta
							</div>
						</Button>
					) : (
						<Button onClick={() => navigateLogin?.()}>
							<div className='account-button-content'>Login</div>
						</Button>
					)}
				</div>
			</div>
			<hr className='header-line' />
		</header>
	)
}

export default Header
