import React, { useEffect, useState } from 'react'
import './index.scss'

export interface ImageInputProps {
	handleImageChange: (file: File) => void
	imageUrl: string | File
}

const ImageInput: React.FC<ImageInputProps> = ({ handleImageChange, imageUrl }) => {
	const [imageSrc, setImageSrc] = useState<string>()

	useEffect(() => {
		if (imageUrl instanceof File) {
			const reader = new FileReader()
			reader.onloadend = () => {
				setImageSrc(reader.result as string)
			}
			reader.readAsDataURL(imageUrl)
		}
	}, [imageUrl])

	return (
		<div className='image-input-container'>
			<img src={imageUrl instanceof File ? imageSrc : imageUrl} alt='Module Image' />
			<div className='image-button'>
				<input
					type='file'
					id='file-upload'
					className='module-button-file'
					onChange={(e) => e.target.files && handleImageChange(e.target.files[0])}
					accept='image/*'
				/>
				<label htmlFor='file-upload' className='module-button-text'>
					Mudar Imagem
				</label>
			</div>
		</div>
	)
}

export default ImageInput
