import { DetailedHTMLProps, InputHTMLAttributes, ReactNode, Ref, forwardRef, useState } from 'react'
import { ReactComponent as EyeSlashIcon } from '../../assets/icons/eye-slash.svg'
import { ReactComponent as EyeIcon } from '../../assets/icons/eye.svg'
import './index.scss'

export interface InputProps
	extends DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement> {
	label?: string
	type?: 'text' | 'password' | 'number' | 'checkbox'
	ref?: Ref<HTMLInputElement>
	icon?: ReactNode
	onKeyDown?: (event: React.KeyboardEvent<HTMLInputElement>) => void
}

const Input = forwardRef<HTMLInputElement, InputProps>(function Input(props: InputProps, ref) {
	const [showPassword, setShowPassword] = useState(false)
	const { label, type, disabled, onChange, value, className, icon, onKeyDown } = props

	return (
		<div
			className={`input-container ${type === 'password' ? (showPassword ? 'text' : 'password') : type} ${disabled && 'disabled'} ${className}`}
		>
			<input
				{...props}
				type={type === 'password' ? (showPassword ? 'text' : 'password') : type}
				className={`default-input ${!!value && 'filled'} ${!!icon && 'with-icon'}`}
				ref={ref}
				onChange={onChange}
				onKeyDown={onKeyDown}
			/>
			{icon && <div className='icon-container'>{icon}</div>}
			<label className='label' htmlFor='default-input'>
				{label}
			</label>
			{type === 'password' && (
				<div className='toggle-password-icon' onClick={() => setShowPassword(!showPassword)}>
					{showPassword ? <EyeIcon /> : <EyeSlashIcon />}
				</div>
			)}
		</div>
	)
})

export default Input
