import { DetailedHTMLProps, InputHTMLAttributes, MouseEventHandler, Ref, forwardRef } from 'react'
import './index.scss'

export interface RadioInputProps
	extends DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement> {
	label?: string
	ref?: Ref<HTMLInputElement>
	onButtonClick?: MouseEventHandler<HTMLButtonElement>
	disabled?: boolean
}

const RadioInput = forwardRef<HTMLInputElement, RadioInputProps>(function Input(
	props: RadioInputProps,
	ref
) {
	const { onButtonClick, disabled, onInput, onChange, ...restProps } = props

	const { label, value, className, id } = restProps

	return (
		<div className={`${className} div-input-radio`}>
			<input
				{...restProps}
				disabled={disabled}
				type='checkbox'
				onChange={onChange}
				className={`radio-input ${!!value && 'filled'}`}
				ref={ref}
			></input>
			{onInput === undefined ? (
				<label className='label-radio'>{label}</label>
			) : (
				<div className='editable-div'>
					<p
						className='label-radio-editable'
						id={'editable-' + id}
						contentEditable='true'
						data-name={id?.toString()}
						suppressContentEditableWarning={true}
						onInput={onInput}
					>
						{label}
					</p>
					<div className='minus-button-div'>
						<button className='minus-button' onClick={onButtonClick} id={'button-' + id}>
							<span className='minus-icon'></span>
						</button>
					</div>
				</div>
			)}
		</div>
	)
})

export default RadioInput
