import { useState } from 'react'
import { InputProps } from '../Input'
import './index.scss'
import { Loader } from '../Loader'

export interface SelectInputItem<T> {
	label: string
	value: T
}

export interface SelectProps<T> extends InputProps {
	multiple?: boolean
	style?: React.CSSProperties
	options: SelectInputItem<T>[]
	isLoading?: boolean
	onSelectOption: (value?: T) => void
	isOptionSelected: (value?: T) => boolean
}

function Select<T>({
	isOptionSelected,
	label,
	onSelectOption,
	options,
	multiple,
	value,
	style,
	isLoading
}: SelectProps<T>) {
	const [open, setOpen] = useState(false)

	const handleToggle = () => {
		setOpen(!open)
	}

	const handleOptionClick = (optionValue: T) => {
		onSelectOption(optionValue)
		if (!multiple) {
			setOpen(false)
		}
	}

	return (
		<div className='select-container'>
			<div className={`select-header ${open ? 'open' : ''}`} style={style} onClick={handleToggle}>
				<div className='select-value'>{value}</div>
				<div className={`select-arrow ${open ? 'down' : 'up'}`}>▲</div>
				<label style={style} className={`select-label ${value || open ? 'active' : ''}`}>
					{label}
				</label>
			</div>
			<div className='select-bottom'>
				{isLoading && open ? (
					<Loader styleLoader={'small'} />
				) : (
					open && (
						<ul className='select-list'>
							{options.map((option, index) => (
								<li key={index} onClick={() => handleOptionClick(option.value)}>
									{multiple && (
										<input
											className='selected-checkbox'
											type='checkbox'
											checked={isOptionSelected(option.value)}
											readOnly
										/>
									)}
									{option.label}
								</li>
							))}
						</ul>
					)
				)}
			</div>
		</div>
	)
}

export default Select
