import React, { useEffect, useState } from 'react'
import ActivitiesPage from '../../Common/Activities'
import EditableText from '../../Common/Activities/components/EditableText'
import Paper from '../../Common/Activities/components/Paper'
import ActivityList from '../../Common/Activities/components/ActivityList'
import {
	ActivityDto,
	ActivityListDto,
	ActivityStatus,
	ActivityType,
	ActivityUpdateListDtoRequestPayload,
	AlternativeDto,
	CourseFeedbackDto
} from '../../../dtos/ActivityDto'
import { useModal } from '../../../providers/Modal/ModalProvider'
import ActivityViewer from '../../Common/Activities/components/ActivityViewer'
import { useLocation, useParams } from 'react-router-dom'
import { useCourseModuleActivityFeedback } from '../../../services/core/courses/mutations'
import Feedback from '../../../components/Feedback'
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'
import EndModule from '../../../components/EndModule'
import { useGetAllUsersActivities } from '../../../services/core/users/queries'
import { useUserUpdateActivity } from '../../../services/core/users/mutations'
import { UpdateProgressUser } from '../../../dtos/UserDto'

export interface CheckboxInputTypes {
	label: string
	isChecked: boolean
}

const ColaboratorActivities: React.FC = () => {
	const [activities, setActivities] = useState<ActivityDto[]>([])
	const [activitiesList, setActivitiesList] = useState<ActivityListDto[]>([])
	const [updatedActivitiesList, setUpdatedActivitiesList] =
		useState<ActivityUpdateListDtoRequestPayload>({ activityList: [] })
	const [selectedAlternatives, setSelectedAlternatives] = useState<AlternativeDto[]>([])
	const [progress, setProgress] = useState<number>(0)
	const [selectedActivity, setSelectedActivity] = useState<ActivityDto>()
	const [updateProgress, setUpdateProgress] = useState<UpdateProgressUser>({ isDone: true })
	const [isFeebackPending, setIsFeebackPending] = useState<boolean>(false)
	const [showError, setShowError] = useState<boolean>(false)
	const [isLastModule, setIsLastModule] = useState<boolean>(false)
	const [feedback, setFeedback] = useState<CourseFeedbackDto>({})
	const [activityIdToUpdate, setActivityIdToUpdate] = useState<number>()

	const location = useLocation()
	const { setModalContent, setVisibility } = useModal()

	const { moduleId: moduleIdParam, courseId: courseIdParam } = useParams()
	const moduleId: number = Number(moduleIdParam)
	const courseId: number = Number(courseIdParam)
	const { data, isLoading } = useGetAllUsersActivities(moduleId, courseId)
	const {
		mutate: feedbackMutate,
		data: feedbackData,
		isPending
	} = useCourseModuleActivityFeedback(courseId, feedback)
	const { navigateCourses, navigateModules } = useNavigation()

	const {
		mutate: updateMutate,
		data: updatedData,
		isPending: isUpdatePending
	} = useUserUpdateActivity(updateProgress, activityIdToUpdate)

	useEffect(() => {
		if (data && activities.length === 0) {
			setActivities(data)
			updateActivitiesList(data)
		}
	}, [data])

	useEffect(() => {
		isPending ? setIsFeebackPending(true) : setIsFeebackPending(false)
	}, [isPending])

	useEffect(() => {
		if (activityIdToUpdate !== undefined) {
			updateMutate()
		}
	}, [activityIdToUpdate])

	useEffect(() => {
		if (location.state && location.state.isLastModule) {
			const { isLastModule } = location.state
			setIsLastModule(isLastModule)
		}
	}, [location.state])

	const onClickFeedbackEnviar = (rating: number) => {
		setFeedback({
			courseId,
			score: rating
		})
	}

	useEffect(() => {
		if (feedback && feedback.score !== undefined) {
			feedbackMutate()
		}
	}, [feedback])

	useEffect(() => {
		if (feedbackData) {
			setVisibility?.(false)
			navigateCourses?.()
		}
	}, [feedbackData])

	const onClickCancelModal = () => {
		setVisibility?.(false)
		navigateCourses?.()
	}

	const onClickNext = () => {
		setVisibility?.(false)
		navigateModules?.({ courseId })
	}

	useEffect(() => {
		if (updatedData) {
			const indexActive = activities.findIndex((activity) => activity?.isDone === false)
			if (indexActive === -1) {
				setProgress(100)
				isLastModule
					? setModalContent?.(
							<Feedback
								onClickConfirmar={onClickFeedbackEnviar}
								isPending={isFeebackPending}
								onClickCancel={onClickCancelModal}
							/>
						)
					: setModalContent?.(<EndModule onClickNext={onClickNext} />)
				setVisibility?.(true)
			} else setProgress((indexActive / activities.length) * 100)
			if (indexActive !== -1) setSelectedActivity(activities[indexActive])
			setShowError(false)
			setSelectedAlternatives([])
		}
	}, [updatedData])

	const updateActivitiesList = (data: ActivityDto[]) => {
		const currentActivitiesList: ActivityListDto[] = data.map((activity, currentIndex) => {
			let status: ActivityStatus = ActivityStatus.TODO
			if (activity.isDone) {
				status = ActivityStatus.DONE
			}

			const isFirstActivity = currentIndex === 0
			const isLastActivity = currentIndex + 1 === data.length
			const isPreviousActivityDone = data[currentIndex - 1] && data[currentIndex - 1].isDone

			if (isFirstActivity && !activity.isDone) {
				status = ActivityStatus.DOING
			}

			if (!isFirstActivity) {
				if (isLastActivity && !activity.isDone && isPreviousActivityDone)
					status = ActivityStatus.DOING
				if (!activity.isDone && isPreviousActivityDone) status = ActivityStatus.DOING
			}

			return {
				id: activity.id,
				status: status,
				name: activity.name
				// name:`Atividade ${currentIndex + 1}`
			}
		})
		const indexActive = data.findIndex((activity) => activity.status === ActivityStatus.DOING)
		if (indexActive !== -1) setSelectedActivity(data[indexActive])
		setActivitiesList(currentActivitiesList)
	}

	useEffect(() => {
		if (activities) {
			const indexActive = activities.findIndex((activity) => activity.isDone === false)
			if (indexActive === -1) {
				setProgress(100)
			}
			if (indexActive !== -1 && (indexActive / activities.length) * 100 !== -Infinity) {
				setSelectedActivity(activities[indexActive])
				setProgress((indexActive / activities.length) * 100)
			}
		}
	}, [activities])

	// TODO query hook to activity

	const onActivityClick = (activityId: number) => {
		const selected = activities.find((a) => a.id === activityId)
		if (activitiesList.find((a) => a.id === activityId)?.status === ActivityStatus.TODO) return
		setSelectedActivity(selected)
	}

	const onPrevClick = () => {
		if (!selectedActivity) return
		const current = activitiesList.findIndex((a) => a.id === selectedActivity.id)
		if (current <= 0) return
		setSelectedActivity(activities.find((a) => a.id === activities[current - 1].id))
	}

	const onNextClick = () => {
		if (!selectedActivity) return
		const current = activitiesList.findIndex((a) => a.id === selectedActivity.id)
		if (current === activities.length - 1) return
		if (activitiesList[current + 1].status === ActivityStatus.TODO) return
		setSelectedActivity(activities.find((a) => a.id === activities[current + 1].id))
	}

	const updateActiveListValidate = () => {
		const currentIndex = activitiesList.findIndex((a) => a.id === selectedActivity?.id)

		activities[currentIndex].status = ActivityStatus.DONE
		activities[currentIndex].isDone = true
		if (currentIndex + 1 < activities.length) {
			activities[currentIndex + 1].status = ActivityStatus.DOING
		}
		const updateActivitesList = activitiesList
			.map((activity, activityIndex) => {
				if (currentIndex === activityIndex) {
					activitiesList[currentIndex].status = ActivityStatus.DONE
					return { ...activity, status: ActivityStatus.DONE }
				}
				if (currentIndex + 1 === activityIndex) {
					activitiesList[currentIndex + 1].status = ActivityStatus.DOING
					return { ...activity, status: ActivityStatus.DOING }
				}
			})
			.filter((activity) => activity !== undefined)
		setUpdatedActivitiesList({ activityList: updateActivitesList as ActivityListDto[] })
		setUpdateProgress({ isDone: true })
		setActivityIdToUpdate(activities[currentIndex].id)
		setActivities(activities)
		setActivitiesList(activitiesList)
	}

	const onValidateClick = () => {
		if (selectedActivity?.type === ActivityType.MEDIA) {
			const currentIndex = activitiesList.findIndex((a) => a.id === selectedActivity.id)
			activitiesList[currentIndex].status = ActivityStatus.DONE
			updateActiveListValidate()
		} else {
			const correctSelectedAlternatives: AlternativeDto[] | undefined =
				selectedActivity?.quiz?.[0]?.questions?.[0]?.alternatives
					.map((alternative) => {
						if (alternative.isCorrect) {
							return alternative
						}
					})
					.filter((alternative): alternative is AlternativeDto => alternative !== undefined)

			if (selectedAlternatives.length !== correctSelectedAlternatives?.length) {
				setShowError(true)
				return
			}
			const isCorrect = correctSelectedAlternatives.every((correctAlternative) =>
				selectedAlternatives.some(
					(alternativeSelected) =>
						correctAlternative.id === alternativeSelected.id &&
						correctAlternative.text === alternativeSelected.text &&
						correctAlternative.isCorrect === alternativeSelected.isCorrect
				)
			)

			isCorrect ? updateActiveListValidate() : setShowError(true)
		}
	}

	return (
		<ActivitiesPage>
			<div className='activity-info-container'>
				<EditableText className='name' text='Atividades' readonly={true} />
				<EditableText
					className='description'
					readonly={true}
					text='Aqui você poderá criar e editar as atividades que os colaboradores usarão para seus estudos.'
				/>
			</div>
			<div className='activity-content-container'>
				<Paper>
					<ActivityList
						selected={selectedActivity}
						activities={activitiesList}
						onSelect={onActivityClick}
					/>
				</Paper>
				<Paper>
					<ActivityViewer
						isUpdatePending={isUpdatePending}
						showError={showError}
						activity={selectedActivity}
						selectedAlternatives={selectedAlternatives}
						setSelectedAlternatives={setSelectedAlternatives}
						canEdit={false}
						onValidateClick={onValidateClick}
						isLoading={isLoading}
						onPrevClick={onPrevClick}
						onNextClick={onNextClick}
						progress={progress}
					/>
				</Paper>
			</div>
		</ActivitiesPage>
	)
}

export default ColaboratorActivities
