import { useEffect, useState } from 'react'
import { Card } from '../../../components/Card'
import { ButtonProps } from '../../../components/Button'
import { CourseDto } from '../../../dtos/CourseDto'
import { Loader } from '../../../components/Loader'
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'
import { useGetAllCourses } from '../../../services/core/courses/queries'
import ProgressTracker from '../../../components/ProgressTracker'

const CollaboratorCourse: React.FC = () => {
	const { navigateModules } = useNavigation()
	const [courses, setCourses] = useState<CourseDto[]>([])
	const { data, isLoading } = useGetAllCourses()

	useEffect(() => {
		if (data) setCourses(data)
	}, [data])

	const renderCard = (item: CourseDto) => {
		const buttons: ButtonProps[] = [
			{
				variant: 'filled',
				color: 'primary',
				onClick: () => navigateModules?.({ courseId: item.id }),
				children: (
					<div className='card-button-div'>
						<p className='card-button-text'>Entrar</p>
					</div>
				)
			}
		]
		return (
			<Card title={item.name} buttons={buttons} imageUrl={item.imageUrl} text={item.description} />
		)
	}

	return (
		<div className='course-container'>
			<div className='course-top'>
				<h1 className='course-title'>Cursos</h1>
				<p className='course-text'>
					Na biblioteca de cursos, encontre trajetórias de aprendizado para impulsionar sua carreira
					e comece sua jornada conosco.
				</p>
			</div>
			<div className='course-middle'>
				<div>
					<ProgressTracker quantity={courses} progress={3} />
				</div>
				<div className='course-cards'>
					{isLoading ? <Loader /> : courses.map((e) => renderCard(e))}
				</div>
			</div>
		</div>
	)
}

export default CollaboratorCourse
