import React from 'react'
import './index.scss'
import imagecard1 from '../../../assets/images/img-carousel-card1.png'
import imagecard2 from '../../../assets/images/img-carousel-card2.png'
import imagecard3 from '../../../assets/images/img-carousel-card3.png'
import Carousel from '../../../components/Carousel'
import { Button } from '../../../components/Button'
import { useAuth } from '../../../providers/Auth/AuthProvider'
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'

const HomeCo: React.FC = () => {
	const { user } = useAuth()
	const { navigateCourses } = useNavigation()

	const slides = [
		{
			title: 'Como é o Onboarding?',
			text: 'O onboarding não é apenas uma integração, mas sim a base para um relacionamento duradouro entre empresa e talentos. Seguir nosso método pode otimizar em 46% o tempo do RH com ações operacionais do onboarding.',
			image: imagecard1,
			variant: 'gradient-primary' as const
		},
		{
			title: 'Nossa Metodologia',
			text: 'As metodologias de onboarding são baseadas em learning science. Seguindo o indicado, diminua o early turnover e aumente a performance do seu novo talento!',
			image: imagecard2,
			variant: 'gradient-secondary' as const
		},
		{
			title: 'Organize sua equipe',
			text: 'Tenha acesso rápido a todos os seus colaboradores. Acompanhe o progresso deles e insira novos talentos na sua realidade!',
			image: imagecard3,
			variant: 'gradient-terciary' as const
		}
	]

	return (
		<div className='home-container'>
			<div className='home-content'>
				<h1 className='home-title'>
					{' '}
					Bem-Vindo, <span className='home-title-name'>{user?.friendlyName}</span>
				</h1>
				<div className='home-carousel'>
					<Carousel slides={slides} />
				</div>
				<div className='home-divider'>
					<div className='home-line primary'>
						<br />
					</div>
					<h2 className='home-subtitle'>Cursos</h2>
					<div className='home-line secondary'>
						<br />
					</div>
				</div>
				<div className='home-bottom'>
					<p className='home-bottom-text'>
						Para iniciar sua jornada, clique no botão abaixo para acessar os cursos disponíveis.
						Estamos aqui para ajudá-lo(a) em cada etapa do seu desenvolvimento!
					</p>
					<div className='home-button-container'>
						<Button
							variant='filled'
							color='primary'
							size='big'
							// onClick={() => navigateCourses?.({ areaId: 1 })}
							onClick={() => {
								navigateCourses?.({})
							}}
						>
							<p className='home-button-text'>Iniciar</p>
						</Button>
					</div>
				</div>
			</div>
		</div>
	)
}

export default HomeCo
