import { useEffect, useState } from 'react'
import { Card } from '../../../components/Card'
import { ButtonProps } from '../../../components/Button'
import { ModuleDto } from '../../../dtos/ModuleDto'
import { Loader } from '../../../components/Loader'
import ProgressTracker from '../../../components/ProgressTracker'
import { useGetAllCourseModules } from '../../../services/core/courses/queries'
import { useParams } from 'react-router-dom'
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'

const CollaboratorModules: React.FC = () => {
	const [modules, setModules] = useState<ModuleDto[]>([])
	const [isLastModule, setIsLastModule] = useState<boolean>()
	const [moduleSelected, setModuleSelected] = useState<ModuleDto>()

	const { courseId: moduleIdParam } = useParams()
	const courseId: number = Number(moduleIdParam)

	const { navigateActivityList } = useNavigation()

	const { data, isLoading } = useGetAllCourseModules(courseId)

	useEffect(() => {
		if (isLastModule !== undefined) redirectActivity(moduleSelected!)
	}, [isLastModule])

	useEffect(() => {
		if (data) setModules(data)
	}, [data])

	const redirectActivity = (module: ModuleDto) => {
		navigateActivityList?.({
			props: {
				courseId,
				moduleId: module.id
			},
			state: {
				moduleTitle: module.name,
				moduleDescription: module.description,
				isLastModule: isLastModule
			}
		})
	}

	const redirectActivityFunction = (item: ModuleDto, index: number) => {
		setModuleSelected(item)
		if (modules.length === index + 1) setIsLastModule(true)
		if (modules.length !== index + 1) setIsLastModule(false)
	}

	const renderCard = (item: ModuleDto, index: number) => {
		const buttons: ButtonProps[] = [
			{
				variant: 'filled',
				color: 'primary',
				children: (
					<div className='card-button-div'>
						<p
							className='card-button-text'
							onClick={() => {
								redirectActivityFunction(item, index)
							}}
						>
							Entrar
						</p>
					</div>
				)
			}
		]
		return <Card title={item.name} imageUrl={item.imageUrl} buttons={buttons} />
	}

	return (
		<div className='management-container'>
			<div className='management-top'>
				<h1 className='management-title'>Módulos</h1>
				<p className='management-text'>
					Aqui você poderá acessar os módulos e acompanhar o avanço do seu estudo pela barra de
					progresso.
				</p>
			</div>
			<div className='management-middle'>
				<div>
					<ProgressTracker quantity={modules} progress={2} />
				</div>
				<div className='management-cards'>
					{isLoading ? <Loader /> : modules.map((e, index) => renderCard(e, index))}
				</div>
			</div>
		</div>
	)
}

export default CollaboratorModules
