import React from 'react'
import { ReactComponent as TodoIcon } from '../../../../../assets/icons/empty-circle.svg'
import { ReactComponent as AddIcon } from '../../../../../assets/icons/circle-add-icon.svg'
import { ReactComponent as DoingIcon } from '../../../../../assets/icons/circle-inner-circle.svg'
import { ReactComponent as DoneIcon } from '../../../../../assets/icons/check-circle.svg'
import { ActivityDto, ActivityListDto, ActivityStatus } from '../../../../../dtos/ActivityDto'
import './index.scss'

export interface ActivityListProps {
	activities?: ActivityListDto[]
	canEdit?: boolean
	selected?: ActivityDto
	onSelect?: (activityId: number) => void
	handleCreate?: () => void
}

const ActivityList: React.FC<ActivityListProps> = ({
	activities,
	selected,
	onSelect,
	canEdit,
	handleCreate
}) => {
	const renderActivityStatusIcon = (activity: ActivityListDto, canEdit: boolean) => {
		if (selected?.idActivitySelected === activity.id && canEdit) return <DoingIcon />
		switch (activity.status) {
			case ActivityStatus.TODO:
				return <TodoIcon />
			case ActivityStatus.DOING:
				return <DoingIcon />
			case ActivityStatus.DONE:
				return <DoneIcon />
			default:
				if (selected && selected.id === activity.id) return <DoingIcon />
				return <TodoIcon />
		}
	}

	return (
		<div className={`activity-list-container ${selected && 'selected'}`}>
			<div className='teste'>
				{activities &&
					activities.map((activity, index) => (
						<div
							key={index}
							className={`${
								!canEdit && activity.status === ActivityStatus.TODO
									? 'activity-item-container'
									: 'activity-item-container edit'
							} ${selected && selected.id === activity.id && 'selected'}`}
							onClick={() => onSelect?.(activity.id)}
						>
							<div className='icon-div'>{renderActivityStatusIcon(activity, canEdit!)}</div>{' '}
							<div className='text-list'> {activity.name} </div>
						</div>
					))}
				{canEdit && (
					<div className='activity-item-container' onClick={handleCreate}>
						<AddIcon className='add-icon' /> Criar
					</div>
				)}
			</div>
		</div>
	)
}

export default ActivityList
