import React from 'react'
import './index.scss'
import { AlternativeDto } from '../../../../../dtos/ActivityDto'
import Paper from '../Paper'
import ActivityCardComponent, { QuestionTypes } from '../card-activity'

export interface ActivityManagerProps {
	questionType?: QuestionTypes
	options: AlternativeDto[]
	handleTextOptionChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	onCheckboxChangeCheckbox: (event: React.ChangeEvent<HTMLInputElement>) => void
	onRadioChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	addOption: () => void
	handleRemoveFile: (index: number) => void
	files: File[]
	isPending: boolean | undefined
	changeQuestionType: (event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => void
	handleQuestionChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	removeOption: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
	isDisabled: boolean | undefined
	isPendingEdit: boolean | undefined
	question: string
	isEditing: boolean
	isPendingUploadMedia: boolean
	isPendingGetById: boolean
	isCreatingByActivityList: boolean
	onClickCreate: VoidFunction
	onClickUpdate: VoidFunction
	onClickPlusExternalContent?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
}

const ActivityManagerViewer: React.FC<ActivityManagerProps> = ({
	isPendingUploadMedia,
	isPendingGetById,
	questionType,
	question,
	options,
	handleTextOptionChange,
	onCheckboxChangeCheckbox,
	onRadioChange,
	handleRemoveFile,
	addOption,
	files,
	changeQuestionType,
	handleQuestionChange,
	isEditing,
	isPendingEdit,
	onClickUpdate,
	removeOption,
	isPending,
	isDisabled,
	onClickCreate,
	isCreatingByActivityList,
	onClickPlusExternalContent
}) => {
	return (
		<Paper>
			<div className='activity-manager-container'>
				<div className='activity-manager-content'>
					<ActivityCardComponent
						isPendingUploadMedia={isPendingUploadMedia}
						isPendingGetById={isPendingGetById}
						isCreatingByActivityList={isCreatingByActivityList}
						isPendingEdit={isPendingEdit}
						onClickUpdate={onClickUpdate}
						isEditing={isEditing}
						addOption={addOption}
						changeQuestionType={changeQuestionType}
						handleQuestionChange={handleQuestionChange}
						handleRemoveFile={handleRemoveFile}
						handleTextOptionChange={handleTextOptionChange}
						isDisabled={isDisabled}
						isPending={isPending}
						onCheckboxChangeCheckbox={onCheckboxChangeCheckbox}
						onClickCreate={onClickCreate}
						onRadioChange={onRadioChange}
						options={options}
						question={question}
						removeOption={removeOption}
						questionType={questionType}
						files={files}
						onClickPlusExternalContent={onClickPlusExternalContent}
					></ActivityCardComponent>
				</div>
			</div>
		</Paper>
	)
}

export default ActivityManagerViewer
