import React, { Dispatch, SetStateAction } from 'react'
import './index.scss'
import { ActivityDto, ActivityType, AlternativeDto } from '../../../../../dtos/ActivityDto'
import Paper from '../Paper'
import Question from '../Question'
import { Button } from '../../../../../components/Button'
import { ReactComponent as CircleArrowIcon } from '../../../../../assets/icons/circle-arrow.svg'
import ProgressBar from '../ProgressBar'
import { Loader } from '../../../../../components/Loader'
import { ReactComponent as AlertIcon } from '../../../../../assets/icons/error-svgrepo-com.svg'
import MediaComponent from '../Media'

export interface ActivityViewerProps {
	activity?: ActivityDto
	canEdit?: boolean
	isEditing?: boolean
	onPrevClick?: () => void
	onNextClick?: () => void
	isDeleteLoading?: boolean
	onEditClick?: (activityId: number) => void
	onDeleteClick?: (activityId: number) => void
	selectedAlternatives?: AlternativeDto[]
	setSelectedAlternatives?: Dispatch<SetStateAction<AlternativeDto[]>>
	onValidateClick?: () => void
	isLoading?: boolean
	progress?: number
	showError?: boolean
	isUpdatePending?: boolean
}

const ActivityViewer: React.FC<ActivityViewerProps> = ({
	activity,
	canEdit,
	onPrevClick,
	onNextClick,
	onEditClick,
	isDeleteLoading,
	isLoading,
	setSelectedAlternatives,
	selectedAlternatives,
	onValidateClick,
	isUpdatePending,
	onDeleteClick,
	showError,
	progress
}) => {
	return (
		<Paper>
			<div className='activity-viewer-container'>
				<div className={`${canEdit ? 'just-spacing' : 'activity-viewer-header'}`}>
					{!canEdit && <ProgressBar percentage={progress || 0} />}
				</div>

				<div className='activity-viewer-content'>
					{activity ? (
						<>
							{activity.type === ActivityType.QUESTION ? (
								<Question
									order={activity.order}
									question={activity?.quiz?.[0]?.questions?.[0] ?? null}
									disabled={canEdit}
									setSelectedAlternatives={setSelectedAlternatives}
									selectedAlternatives={selectedAlternatives}
								/>
							) : (
								<>
									<MediaComponent
										content={activity?.contents}
										order={activity.order}
										name={activity.name}
									/>
								</>
							)}
						</>
					) : (
						<p>Selecione uma atividade da lista.</p>
					)}
				</div>
				<div className='activity-viewer-bottom'>
					{activity && (
						<div className='buttons-container'>
							<CircleArrowIcon className='arrow-icon prev' onClick={onPrevClick} />
							{canEdit ? (
								<>
									<Button variant='outlined' color='black'>
										{isDeleteLoading || isLoading ? (
											<Loader />
										) : (
											<div className='button-text' onClick={() => onDeleteClick?.(activity.id)}>
												Deletar
											</div>
										)}
									</Button>
									{/* {activity.activity.type === ActivityType.QUESTION ? (
										<Button onClick={() => onEditClick?.(activity.activity.id)}>
											<div className='button-text'> Editar </div>
										</Button>
									) : (
										<> </>
									)} */}
								</>
							) : (
								<Button disabled={isUpdatePending} onClick={onValidateClick}>
									<p className='button-text'>
										{isUpdatePending ? <Loader styleLoader='small' /> : 'Validar'}
									</p>
								</Button>
							)}
							<CircleArrowIcon className='arrow-icon next' onClick={onNextClick} />
						</div>
					)}
					{showError ? (
						<div className='alert-div'>
							<AlertIcon className='alert-icon' />
							<p className='error-text'> Resposta errada, tente novamente </p>
						</div>
					) : (
						<></>
					)}
				</div>
			</div>
		</Paper>
	)
}

export default ActivityViewer
