import './index.scss'

import ReactPlayer from 'react-player'
import EditableText from '../EditableText'
import { Worker, Viewer } from '@react-pdf-viewer/core'
// Import the main component

// Import the styles
import '@react-pdf-viewer/core/lib/styles/index.css'
import { ContentMedia, ContentType } from '../../../../../dtos/ActivityDto'

export interface MediaComponentProps {
	content?: ContentMedia[]
	order?: number
	name?: string
}

const renderContentUrl = (contentUrl: string, contentType: ContentType) => {
	if (contentType === ContentType.IMAGE) {
		return <img src={contentUrl} className='image' alt='Content Image' />
	}
	if (contentType === ContentType.VIDEO) {
		return (
			<ReactPlayer
				className='react-player'
				url={contentUrl}
				width='100%'
				height='100%'
				controls={true}
			/>
		)
	}
	if (contentType === ContentType.PDF) {
		return (
			<Worker workerUrl='https://unpkg.com/pdfjs-dist@3.4.120/build/pdf.worker.min.js'>
				<div style={{ height: '50vh' }}>
					<Viewer fileUrl={contentUrl} />
				</div>
			</Worker>
		)
	}

	return <img src={contentUrl} className='image' alt='Content Image' />
}

export const MediaComponent: React.FC<MediaComponentProps> = (props: MediaComponentProps) => {
	return (
		<div className='media-content-container'>
			<div className='media-header'>
				{props.order !== undefined ? props.order + '.' : ''}{' '}
				<EditableText readonly={true} text={props.name} />
			</div>
			<div className='media-content'>
				{Array.isArray(props.content) ? (
					props.content?.map((content, index) => {
						return (
							<div key={index} className='content-div'>
								{renderContentUrl(content.url, content.type)}
							</div>
						)
					})
				) : (
					<></>
				)}
			</div>
		</div>
	)
}

export default MediaComponent
