import React, { Dispatch, SetStateAction } from 'react'
import { AlternativeDto, QuestionDto, QuestionType } from '../../../../../dtos/ActivityDto'
import EditableText from '../EditableText'
import './index.scss'
import RadioInput from '../../../../../components/RadioInput'
import CheckboxInput from '../../../../../components/CheckboxInput'

export interface QuestionProps {
	order?: number
	question?: QuestionDto | null
	canEdit?: boolean
	disabled?: boolean
	selectedAlternatives?: AlternativeDto[]
	setSelectedAlternatives?: Dispatch<SetStateAction<AlternativeDto[]>>
}

const Question: React.FC<QuestionProps> = ({
	order,
	question,
	canEdit,
	selectedAlternatives,
	disabled,
	setSelectedAlternatives
}) => {
	const onCheckboxInputChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		if (selectedAlternatives !== undefined && setSelectedAlternatives !== undefined) {
			const altId = parseInt(event.target.value)
			const oldSelected = [...selectedAlternatives]

			if (oldSelected.find((a) => a.id === altId)) {
				setSelectedAlternatives([])
				return
			}
			const alt = question?.alternatives.find((a) => a.id === altId)
			if (alt) setSelectedAlternatives([alt])
		}
	}

	const onRadioInputChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		if (selectedAlternatives !== undefined && setSelectedAlternatives !== undefined) {
			const altId = parseInt(event.target.value)
			const oldSelected = [...selectedAlternatives]

			if (oldSelected.find((a) => a.id === altId)) {
				setSelectedAlternatives(oldSelected.filter((a) => a.id !== altId))
				return
			}
			const alt = question?.alternatives.find((a) => a.id === altId)
			if (alt) setSelectedAlternatives([...oldSelected, alt])
		}
	}

	return (
		<div className='quiz-container'>
			<div className='quiz-header'>
				{order}. <EditableText readonly={!canEdit} text={question?.text} />
			</div>
			<div className='quiz-content'>
				{question?.alternatives.map((alt, index) => (
					<div key={index} className='quiz-alternative'>
						{question.type === QuestionType.SINGLE_CHOISE ? (
							<CheckboxInput
								disabled={disabled}
								label={alt.text}
								onChange={onCheckboxInputChange}
								value={alt.id}
								checked={selectedAlternatives?.includes(alt)}
							/>
						) : (
							<RadioInput
								disabled={disabled}
								label={alt.text}
								onChange={onRadioInputChange}
								value={alt.id}
								checked={selectedAlternatives?.includes(alt)}
							/>
						)}
					</div>
				))}
			</div>
		</div>
	)
}

export default Question
