import React from 'react'
import './index.scss'
import ActivityQuestionContent from '../question-content'
import { Button } from '../../../../../components/Button'
import { Loader } from '../../../../../components/Loader'
import { AlternativeDto } from '../../../../../dtos/ActivityDto'
import EditableText from '../EditableText'
import { useNavigation } from '../../../../../providers/Navigation/NavigationProvider'

const CHECKBOX = 'Checkbox'
const MULTIPLE_CHOICE = 'Múltipla Escolha'
const EXTERNAL_CONTENT = 'Conteúdo Externo'

export enum QuestionTypes {
	CHECKBOX = 'Checkbox',
	MULTIPLE_CHOICE = 'Múltipla Escolha',
	EXTERNAL_CONTENT = 'Conteúdo Externo'
}

const questionTypes = [CHECKBOX, MULTIPLE_CHOICE, EXTERNAL_CONTENT]

export interface ActivityCardProps {
	questionType?: QuestionTypes
	options: AlternativeDto[]
	handleTextOptionChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	onCheckboxChangeCheckbox: (event: React.ChangeEvent<HTMLInputElement>) => void
	onRadioChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	addOption: () => void
	handleRemoveFile: (index: number) => void
	files: File[]
	isPending: boolean | undefined
	changeQuestionType: (event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => void
	handleQuestionChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	removeOption: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
	isDisabled: boolean | undefined
	question: string
	isEditing: boolean
	isPendingUploadMedia: boolean
	isPendingGetById: boolean
	isCreatingByActivityList: boolean
	onClickCreate: VoidFunction
	onClickUpdate: VoidFunction
	isPendingEdit: boolean | undefined
	onClickPlusExternalContent?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
}

const ActivityCardComponent: React.FC<ActivityCardProps> = (props: ActivityCardProps) => {
	const { navigateHome } = useNavigation()

	return (
		<div className='activity-card-container'>
			<div className='activity-card-content'>
				<div className='div-title'>
					<p
						className={`title ${props.isEditing || props.isCreatingByActivityList ? 'without-chevron' : 'with-chevron'}`}
					>
						{' '}
						{props.questionType}{' '}
					</p>
					{!props.isEditing && !props.isCreatingByActivityList && (
						<div className='div-chevron '>
							<div className='dropdown'>
								<button className='chevron'> </button>
								<div className='dropdown-options'>
									{questionTypes.map((question, indexQuestion) => (
										<div key={indexQuestion}>
											<a href='#' onClick={props.changeQuestionType}>
												{question}
											</a>
										</div>
									))}
								</div>
							</div>
						</div>
					)}
				</div>
				<hr></hr>
				<EditableText
					className='question'
					onInput={props.handleQuestionChange}
					id='question'
					text={props.question}
				/>
				<div className='activity-question-content-div'>
					{props.isPendingGetById ? (
						<div className='loader-div'>
							<Loader styleLoader='small' />
						</div>
					) : (
						<ActivityQuestionContent
							options={props.options}
							addOption={props.addOption}
							handleTextOptionChange={props.handleTextOptionChange}
							onCheckboxChangeCheckbox={props.onCheckboxChangeCheckbox}
							removeoption={props.removeOption}
							questionType={props.questionType}
							onRadioChange={props.onRadioChange}
							onClickPlusExternalContent={props.onClickPlusExternalContent}
							files={props.files}
							handleRemoveFile={props.handleRemoveFile}
						></ActivityQuestionContent>
					)}
				</div>
				<div className='buttons-container'>
					<Button
						variant='filled'
						color='secondary'
						onClick={() =>
							props.isEditing || props.isCreatingByActivityList
								? window.history.back()
								: navigateHome?.()
						}
					>
						<p className='button-text'>Cancelar</p>
					</Button>
					{props.isEditing ? (
						<Button
							variant='filled'
							color='primary'
							disabled={props.isDisabled || props.isPendingEdit}
							onClick={props.onClickUpdate}
						>
							<p className='button-message'>
								{props.isPendingEdit ? <Loader styleLoader='small' /> : 'Editar'}
							</p>
						</Button>
					) : (
						<Button
							variant='filled'
							color='primary'
							disabled={props.isDisabled || props.isPending || props.isPendingUploadMedia}
							onClick={props.onClickCreate}
						>
							<p className='button-message'>
								{props.isPending || props.isPendingUploadMedia ? (
									<Loader styleLoader='small' />
								) : (
									'Criar'
								)}
							</p>
						</Button>
					)}
				</div>
			</div>
		</div>
	)
}

export default ActivityCardComponent
