import './index.scss'
import { useModal } from '../../../../../providers/Modal/ModalProvider'
import { useEffect, useState } from 'react'
import { Button } from '../../../../../components/Button'
import { ModalHeader, ParagraphInterface } from '../../../../../components/Header-Modal'
import Select, { SelectInputItem } from '../../../../../components/SelectInput'
import DragNdrop from '../../../../../components/DragNDropFile'

const externalContentTypes: SelectInputItem<string>[] = [
	{
		label: 'pdf',
		value: '.pdf'
	},
	{
		label: 'imagem',
		value: 'image/*'
	},
	{
		label: 'audio',
		value: 'audio/*'
	},
	{
		label: 'video',
		value: 'video/*'
	}
]

export interface ExternalContentProps {
	setFiles: React.Dispatch<React.SetStateAction<File[]>>
	files: File[]
	initialFiles: File[]
	updateDisabled: () => void
	onClickCreate: () => void
	resetSelect: boolean
}

export const ExternalContentModal: React.FC<ExternalContentProps> = (
	props: ExternalContentProps
) => {
	const [selectedTeste, setSelectedTeste] = useState<string[]>([])

	useEffect(() => {
		setSelectedTeste([])
	}, [props.resetSelect])

	const { setVisibility } = useModal()

	const headerTitle: ParagraphInterface = {
		text: 'Selecione o estilo de conteúdo',
		style: { fontWeight: 'bold', fontSize: '22px' }
	}
	const headerDescription = {
		text: 'Escolha qual o formato que mais encaixa com seu conteúdo!',
		style: { fontSize: '17px', paddingLeft: '15px' }
	}
	const showDivider = true

	const handleTeste = (value?: string) => {
		if (!value) return
		const oldValue = [...selectedTeste]
		if (selectedTeste.includes(value)) {
			setSelectedTeste(oldValue.filter((v) => v !== value))
			if (selectedTeste.length > 0) return
		}

		setSelectedTeste((prev) => [...prev, value])
	}

	const isOptionSelected = (value?: string) => {
		if (value) return selectedTeste.includes(value)
		return false
	}

	const onClickCancel = () => {
		props.setFiles(props.initialFiles)
	}

	return (
		<div className='container-div-external-content'>
			<div className='header-modal'>
				<ModalHeader
					title={headerTitle}
					description={headerDescription}
					showDivider={showDivider}
				></ModalHeader>
			</div>
			<div className='div-external-content'>
				<Select
					multiple={false}
					options={externalContentTypes}
					value={externalContentTypes
						.filter((v) => selectedTeste.includes(v.value))
						.map((v) => v.label)
						.join(', ')}
					onSelectOption={handleTeste}
					isOptionSelected={isOptionSelected}
					label='Selecione o tipo de arquivo'
					style={{ backgroundColor: '#ffff' }}
				></Select>

				<DragNdrop
					maxFiles={3}
					filesSaved={props.files}
					acceptFileType={selectedTeste}
					onFilesSelected={props.setFiles}
					style={{ width: '100%', height: '15rem' }}
				></DragNdrop>
			</div>
			<div className='buttons-container'>
				<Button
					variant='outlined'
					color='black'
					onClick={() => {
						setVisibility?.(false)
						onClickCancel()
					}}
				>
					<p className='button-text'>Cancelar</p>
				</Button>
				<Button variant='filled' color='black' onClick={props.onClickCreate}>
					<p className='button-text'>Salvar</p>
				</Button>
			</div>
		</div>
	)
}

export default ExternalContentModal
