import React from 'react'
import './index.scss'
import CheckboxInput from '../../../../../components/CheckboxInput'
import { QuestionTypes } from '../card-activity'
import RadioInputCheckbox from '../../../../../components/RadioInput'
import { ReactComponent as DeleteIcon } from '../../../../../assets/icons/icon-delete.svg'
import { AlternativeDto } from '../../../../../dtos/ActivityDto'

export interface ActivityQuestionContentProps {
	options: AlternativeDto[]
	handleTextOptionChange: (event: React.ChangeEvent<HTMLInputElement>) => void
	onCheckboxChangeCheckbox: (event: React.ChangeEvent<HTMLInputElement>) => void
	onRadioChange?: (event: React.ChangeEvent<HTMLInputElement>) => void
	onClickPlusExternalContent?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
	files: File[]
	handleRemoveFile: (index: number) => void
	addOption: () => void
	removeoption: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
	questionType: QuestionTypes | undefined
}

const ActivityQuestionContent: React.FC<ActivityQuestionContentProps> = (
	props: ActivityQuestionContentProps
) => {
	const {
		handleTextOptionChange,
		onCheckboxChangeCheckbox,
		addOption,
		options,
		removeoption,
		questionType,
		onRadioChange,
		onClickPlusExternalContent
	} = props

	return (
		<div className='activity-question-content-container'>
			{options.map((option, optionIndex) => {
				switch (questionType) {
					case QuestionTypes.CHECKBOX:
						return (
							<div key={'option' + -optionIndex} className='div-inputs'>
								<CheckboxInput
									onInput={handleTextOptionChange}
									onButtonClick={removeoption}
									onChange={onCheckboxChangeCheckbox}
									id={`option-${option.id !== undefined ? option.id.toString() : optionIndex.toString()}`}
									name={optionIndex.toString()}
									checked={option.isCorrect}
									label={option.text}
									className='input-child'
								/>
							</div>
						)
					case QuestionTypes.MULTIPLE_CHOICE:
						return (
							<div key={'option' + -optionIndex} className='div-inputs'>
								<RadioInputCheckbox
									onInput={handleTextOptionChange}
									onButtonClick={removeoption}
									onChange={onRadioChange}
									id={`option-${option.id !== undefined ? option.id.toString() : optionIndex.toString()}`}
									name={optionIndex.toString()}
									checked={option.isCorrect}
									label={option.text}
									className='input-child'
								/>
							</div>
						)
				}
			})}
			{questionType !== QuestionTypes.EXTERNAL_CONTENT ? (
				<div className='add-div'>
					<button
						className={
							questionType === QuestionTypes.MULTIPLE_CHOICE ? 'plus-circle-btn' : 'plusbtn'
						}
						onClick={addOption}
					>
						&#43;
					</button>
					<label className='label-add'> Adicionar. </label>
				</div>
			) : (
				<div className='add-div external-content'>
					{props.files.map((file, index) => (
						<div className='file-item' key={index}>
							<div className='file-info'>
								<p>{file.name}</p>
							</div>
							<div className='file-actions' onClick={() => props.handleRemoveFile(index)}>
								<DeleteIcon className='delete-icon' />
							</div>
						</div>
					))}
					<div className='label-button-external-div'>
						<button className={'plusbtn'} onClick={onClickPlusExternalContent}>
							&#43;
						</button>
						<label className='label-add'> Adicionar Conteúdo. </label>
					</div>
				</div>
			)}
		</div>
	)
}

export default ActivityQuestionContent
