import React, { useEffect, useState } from 'react'
import './index.scss'
import { LoginInput } from './components/LoginInput'
import { Button } from '../../components/Button'
import { ReactComponent as DecolaLogo } from '../../assets/icons/decola-logo.svg'
import { ReactComponent as UserIcon } from '../../assets/icons/user-icon.svg'
import { ReactComponent as PasswordIcon } from '../../assets/icons/lock-svgrepo-com.svg'
import { useLoginMutation } from '../../services/auth/login/mutations'
import { Loader } from '../../components/Loader'
import { useAuth } from '../../providers/Auth/AuthProvider'
import { useNavigation } from '../../providers/Navigation/NavigationProvider'

const Login: React.FC = () => {
	const { navigateHome } = useNavigation()
	const [email, setEmail] = useState('')
	const [password, setPassword] = useState('')
	const { setAuthToken, isLogged } = useAuth()
	const { data, mutate, isPending } = useLoginMutation({ email, password })

	useEffect(() => {
		if (isLogged?.()) navigateHome?.()
	}, [isLogged])

	useEffect(() => {
		if (!data) return
		setAuthToken?.(data.accessToken)
		navigateHome?.()
	}, [data])

	const handleChangeEmail = (event: React.ChangeEvent<HTMLInputElement>) => {
		setEmail(event.target.value)
	}

	const handleChangePassword = (event: React.ChangeEvent<HTMLInputElement>) => {
		setPassword(event.target.value)
	}

	const handleKeyDown = (event: React.KeyboardEvent<HTMLInputElement>) => {
		if (event.key === 'Enter') {
			mutate()
		}
	}

	const isLoginButtonDisabled = isPending || !email || !password

	return (
		<div className='login-container'>
			<div className='left-container'></div>
			<div className='right-container'>
				<div className='container-login-right'>
					<div className='right-body'>
						<div className='header-container'>
							<div className='logo-container'>
								<DecolaLogo />
							</div>
							<h1 className='login-title'>
								<span className='title-orange'>Decole</span>
								<span className='title-default'> com a gente</span>
							</h1>
							<h2 className='login-subtitle'>Começe hoje, faça o LOGIN: </h2>
						</div>
						<div className='form'>
							<div className='login-input-container'>
								<LoginInput
									label='Email'
									type='text'
									value={email}
									onChange={handleChangeEmail}
									placeholder='email@example.com.br'
									icon={<UserIcon />}
									onKeyDown={handleKeyDown}
								/>
								<LoginInput
									label='Senha'
									type='password'
									value={password}
									onChange={handleChangePassword}
									placeholder='•••••••'
									icon={<PasswordIcon />}
									onKeyDown={handleKeyDown}
								/>
							</div>
							<div className='login-button-container'>
								<Button
									variant='filled'
									color='primary'
									onClick={mutate}
									disabled={isLoginButtonDisabled}
								>
									<p className='button-message'>
										{isPending ? (
											<div className='modal-button-loader'>
												<Loader />
											</div>
										) : (
											'ENTRAR'
										)}
									</p>
								</Button>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	)
}

export default Login
