import React, { useEffect, useState } from 'react'
import ActivitiesPage from '../../../Common/Activities'
import EditableText from '../../../Common/Activities/components/EditableText'
import Paper from '../../../Common/Activities/components/Paper'
import ActivityList from '../../../Common/Activities/components/ActivityList'
import {
	ActivitiesData,
	ActivityDto,
	ActivityListDto,
	ActivityResponseDto,
	ActivityStatus
} from '../../../../dtos/ActivityDto'
import { useModal } from '../../../../providers/Modal/ModalProvider'
import ActivityViewer from '../../../Common/Activities/components/ActivityViewer'
import { useLocation, useParams } from 'react-router-dom'
import { useNavigation } from '../../../../providers/Navigation/NavigationProvider'
import AddActivityModal from './AddActivityModal.tsx'
import { useGetAllCourseModulesActivities } from '../../../../services/core/courses/queries'
import { QuestionTypes } from '../../../Common/Activities/components/card-activity'
import { useCourseModuleDeleteActivity } from '../../../../services/core/courses/mutations'

export interface CheckboxInputTypes {
	label: string
	isChecked: boolean
}

const OrganizationActivities: React.FC = () => {
	const [activities, setActivities] = useState<ActivityResponseDto[]>([])
	const [activitiesList, setActivitiesList] = useState<ActivityListDto[]>([])
	const [addActivitiesList, setAddActivitiesList] = useState<ActivitiesData[]>([])
	const [activityDeleteId, setactivityDeleteId] = useState<number>()
	const [name, setName] = useState<string>('Atividades')
	const [deletedActivityId, setDeletedActivityId] = useState<number>(0)
	const [description, setDescription] = useState<string>(
		'Aqui você poderá criar e editar as atividades que os colaboradores usarão para seus estudos.'
	)

	const location = useLocation()
	const { navigateCreateEditActivity } = useNavigation()

	const { moduleId: moduleIdParam } = useParams()
	const moduleId: number = Number(moduleIdParam)

	const { courseId: courseIdParam } = useParams()
	const courseId: number = Number(courseIdParam)

	const { data, isLoading, refetch } = useGetAllCourseModulesActivities(moduleId)
	const {
		mutate: mutateDelete,
		data: deletedData,
		isPending: isDeleteLoading
	} = useCourseModuleDeleteActivity(moduleId, activityDeleteId!)

	useEffect(() => {
		if (location.state && location.state.moduleTitle) {
			const { moduleTitle } = location.state
			setName(moduleTitle)
		}
		if (location.state && location.state.moduleDescription) {
			const { moduleDescription } = location.state
			setDescription(moduleDescription)
		}
	}, [location.state])

	// useEffect(() => {
	// 	if (!isLoading) refetch()
	// }, [])

	useEffect(() => {
		setTimeout(() => {
			if (addActivitiesList.length > 0) refetch()
		}, 1000)
	}, [addActivitiesList])

	useEffect(() => {
		if (activities.length > 0) setSelectedActivity(activities[0].activity)
		if (deletedData !== undefined) {
			const activityPositionInActivities: number = activities.findIndex(
				(activity) => activity.activityId === deletedActivityId
			)
			if (activityPositionInActivities !== -1) {
				const activitiesUpdated = activities
					.map((activity, index) => {
						if (activityPositionInActivities === index) return
						if (activityPositionInActivities < index) {
							return {
								...activity,
								order: activity.order !== undefined ? activity.order - 1 : undefined
							}
						}
						return activity
					})
					.filter((activity): activity is ActivityResponseDto => activity !== undefined)
				setActivities(activitiesUpdated)
				updateActivitiesList(activitiesUpdated)
			}
		}
	}, [deletedData])

	useEffect(() => {
		if (data) {
			setActivities(data)
			updateActivitiesList(data)
		}
	}, [data])

	const updateActivitiesList = (data: ActivityResponseDto[]) => {
		const currentActivitiesList: ActivityListDto[] = data.map((activity, currentIndex) => {
			return {
				id: activity.id,
				name: `Atividade ${currentIndex + 1}`
			}
		})
		setActivitiesList(currentActivitiesList)
	}

	const [selectedActivity, setSelectedActivity] = useState<ActivityDto>()
	// TODO query hook to activity

	const { setModalContent, setVisibility } = useModal()

	const onActivityClick = (activityId: number) => {
		const selected = activities.find((a) => a.id === activityId)
		setSelectedActivity({
			...selected?.activity,
			idActivitySelected: selected?.id,
			order: selected?.order,
			status: ActivityStatus.DOING
		} as ActivityDto)
	}

	const onPrevClick = () => {
		if (!selectedActivity) return
		const current = activitiesList.findIndex((a) => a.id === selectedActivity.id)
		if (current <= 0) return
		setSelectedActivity({
			...activities.find((a) => a.id === activities[current - 1].id)?.activity,
			order: activities.find((a) => a.id === activities[current - 1].id)?.order
		} as ActivityDto)
	}

	const onNextClick = () => {
		if (!selectedActivity) return
		const current = activitiesList.findIndex((a) => a.id === selectedActivity.id)
		if (current === activities.length - 1) return
		setSelectedActivity({
			...activities.find((a) => a.id === activities[current + 1].id)?.activity,
			order: activities.find((a) => a.id === activities[current + 1].id)?.order
		} as ActivityDto)
	}

	useEffect(() => {
		if (activityDeleteId) mutateDelete()
	}, [activityDeleteId])

	const onEditClick = (activityId: number) => {
		navigateCreateEditActivity?.({ activityId })
	}

	const onDeleteClick = (activityId: number) => {
		setDeletedActivityId(activityId)
		setactivityDeleteId(activityId)
	}

	const handleTitleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		setEndOfContenteditable(document.getElementById('title') as HTMLInputElement)

		setName(event.target.innerText)
	}

	const handleDescriptionChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		setEndOfContenteditable(document.getElementById('description') as HTMLInputElement)

		setDescription(event.target.innerText)
	}

	const onClickCreateModal = (selectedType: string) => {
		setVisibility?.(false)
		navigateCreateEditActivity?.({
			state: { questionType: selectedType as QuestionTypes, moduleId, courseId }
		})
	}

	const handleCreate = () => {
		setModalContent?.(
			<AddActivityModal
				moduleId={moduleId}
				courseId={courseId}
				initialOrder={activitiesList.length}
				onClickCreate={onClickCreateModal}
				activitiesList={activities}
				setAddActivitiesList={setAddActivitiesList}
			/>
		)
		setVisibility?.(true)
	}

	const setEndOfContenteditable = (contentEditableElement: HTMLInputElement) => {
		if (contentEditableElement === null) return
		let range, selection
		if (document.createRange) {
			range = document.createRange()
			range.selectNodeContents(contentEditableElement)
			range.collapse(false)
			selection = window.getSelection()
			selection?.removeAllRanges()
			selection?.addRange(range)
		}
	}

	return (
		<ActivitiesPage>
			<div className='activity-info-container'>
				<EditableText className='name' text={name} readonly={true} onInput={handleTitleChange} />
				<EditableText
					className='description'
					readonly={true}
					text={description}
					onInput={handleDescriptionChange}
				/>
			</div>
			<div className='activity-content-container'>
				<Paper>
					<ActivityList
						selected={selectedActivity}
						activities={activitiesList}
						canEdit
						onSelect={onActivityClick}
						handleCreate={handleCreate}
					/>
				</Paper>
				<Paper>
					<ActivityViewer
						isEditing
						canEdit
						activity={selectedActivity}
						isDeleteLoading={isDeleteLoading}
						isLoading={isLoading}
						onDeleteClick={onDeleteClick}
						onEditClick={onEditClick}
						onPrevClick={onPrevClick}
						onNextClick={onNextClick}
						progress={40}
					/>
				</Paper>
			</div>
		</ActivitiesPage>
	)
}

export default OrganizationActivities
