import React, { useEffect, useState } from 'react'
import ActivitiesPage from '../../../Common/Activities'
import EditableText from '../../../Common/Activities/components/EditableText'
import Paper from '../../../Common/Activities/components/Paper'
import {
	ActivitiesToAdd,
	ActivityCreateDto,
	ActivityType,
	AlternativeDto,
	QuestionDto
} from '../../../../dtos/ActivityDto'
import { useModal } from '../../../../providers/Modal/ModalProvider'
import ActivityManagerViewer from '../../../Common/Activities/components/ActivityManager'
import { QuestionTypes } from '../../../Common/Activities/components/card-activity'
import ExternalContentModal from '../../../Common/Activities/components/external-content-modal'
import { useLocation, useSearchParams } from 'react-router-dom'
import {
	useActivityMutation,
	useActivityMutationMedia,
	useActivityUpdateMutation
} from '../../../../services/core/activity/mutations'
import { useGetActivitiyById } from '../../../../services/core/activity/queries'
import { useNavigation } from '../../../../providers/Navigation/NavigationProvider'
import { useCourseModuleAddActivity } from '../../../../services/core/courses/mutations'

export interface questionType {
	questionType: QuestionTypes
}

const OrganizationEditCreateActivities: React.FC = () => {
	const [title, setTitle] = useState<string>('Título')
	const [description, setDescription] = useState<string>('Descrição')
	const [searchParams] = useSearchParams()
	const location = useLocation()
	const [question, setQuestion] = useState<string>('Pergunta da Atividade')
	const [isEditing, setIsEditing] = useState<boolean>(false)
	const [isCreatingByActivityList, setisCreatingByActivityList] = useState<boolean>(false)
	const [moduleId, setModuleId] = useState<number>()
	const [currentIndex, setCurrentIndex] = useState<number>()
	const [courseId, setCourseId] = useState<number>(0)
	const [activityToAdd, setActivityToAdd] = useState<ActivitiesToAdd>()
	const [createdActivityId, setCreatedActivityId] = useState<number>()
	const [activityData, setActivityData] = useState<ActivityCreateDto | null>(null)
	const [id] = useState<number>(1)
	const [isDisabled, setisDisabled] = useState<boolean | undefined>(true)
	const [mediaPayload, setMediaPayload] = useState<FormData>()
	const [currentQuestionType, setCurrentQuestionType] = useState<QuestionTypes>(
		QuestionTypes.CHECKBOX
	)
	const [files, setFiles] = useState<File[]>([])
	const [reset, setReset] = useState<boolean>(false)
	const initialOption = {
		text: 'Opção 1',
		isCorrect: false
	}
	const [options, setOptions] = useState<AlternativeDto[]>([initialOption])
	const { navigateHome } = useNavigation()

	const activityId = searchParams.get('activityId')

	const { data: editActivity, isPending: isPendingGetById } =
		activityId !== null ? useGetActivitiyById(Number(activityId)) : { data: null, isPending: false }

	const {
		mutate: updateMutate,
		isPending: isUpdatePending,
		isSuccess: isUpdateSuccess
	} = useActivityUpdateMutation({
		//description: description,
		id: editActivity?.id ?? 10000,
		name: title,
		// order: editActivity?.order ?? 0,
		type: editActivity?.type ?? ActivityType.QUESTION,
		contents: editActivity?.contents !== undefined ? editActivity?.contents : undefined,
		quiz: [
			{
				...editActivity?.quiz,
				questions: [
					editActivity?.quiz?.[0]?.questions?.[0] === undefined
						? {
								alternatives: [],
								text: ''
							}
						: {
								...editActivity.quiz[0]?.questions,
								alternatives: options,
								text: question
							}
				],
				id: 0
			}
		]
	})

	const {
		mutate: mutateMedia,
		data: uploadMediaData,
		isPending: isPendingUploadMedia
	} = useActivityMutationMedia(mediaPayload!)

	useEffect(() => {
		if (searchParams.has('activityId')) {
			setIsEditing(true)
		}
	}, [searchParams])

	useEffect(() => {
		if (files.length > 0) {
			setisDisabled(false)
		}
	}, [files])

	useEffect(() => {
		if (isUpdateSuccess) window.history.back()
	}, [isUpdateSuccess])

	useEffect(() => {
		if (location.state && location.state.questionType) {
			const { questionType } = location.state as questionType
			setCurrentQuestionType(questionType)
		}
		if (location.state && location.state.moduleId) {
			setisCreatingByActivityList(true)
			const { moduleId } = location.state
			const { courseId } = location.state
			const { currentIndex } = location.state
			setModuleId(moduleId)
			setCourseId(courseId)
			setCurrentIndex(currentIndex)
		}
	}, [location.state])

	useEffect(() => {
		if (editActivity && editActivity?.quiz?.[0]?.questions) {
			if (editActivity?.quiz?.[0] !== undefined)
				setOptions(editActivity?.quiz[0]?.questions?.[0]?.alternatives)
			setQuestion(editActivity.quiz?.[0]!.questions?.[0].text)
			setTitle(editActivity.name)
			//setDescription(editActivity.description)

			setCurrentQuestionType(assignQuestionType(editActivity.quiz?.[0]!.questions?.[0]))
		}
		if (editActivity) setisDisabled(false)
	}, [editActivity])

	useEffect(() => {
		if (mediaPayload) mutateMedia()
	}, [mediaPayload])

	useEffect(() => {
		if (uploadMediaData) navigateHome?.()
	}, [uploadMediaData])

	const questionTypeMapping: Record<string, QuestionTypes> = {
		Checkbox: QuestionTypes.CHECKBOX,
		'Múltipla Escolha': QuestionTypes.MULTIPLE_CHOICE,
		'Conteúdo Externo': QuestionTypes.EXTERNAL_CONTENT,
		SINGLE_CHOISE: QuestionTypes.CHECKBOX,
		MULTIPLE_CHOISE: QuestionTypes.MULTIPLE_CHOICE,
		EXTERNAL_CONTENT: QuestionTypes.EXTERNAL_CONTENT
	}

	const assignQuestionType = (question: QuestionDto): QuestionTypes => {
		const correctAlternativesCount = question.alternatives.filter(
			(alternative) => alternative.isCorrect
		).length

		if (correctAlternativesCount === 1) {
			return QuestionTypes.CHECKBOX
		} else if (correctAlternativesCount > 1) {
			return QuestionTypes.MULTIPLE_CHOICE
		}
		return QuestionTypes.CHECKBOX
	}

	// const translateQuestionTypeToEnglish: Record<string, QuestionType> = {
	// 	Checkbox: QuestionType.SINGLE_CHOISE,
	// 	'Múltipla Escolha': QuestionType.MULTIPLE_CHOISE,
	// 	'Conteúdo Externo': QuestionType.EXTERNAL_CONTENT
	// }

	const { setModalContent, setVisibility } = useModal()

	const { data: moduleAddActivity, mutate: mutateModuleActivity } = useCourseModuleAddActivity(
		moduleId!,
		activityToAdd!,
		courseId
	)

	const { data, mutate, isPending } = useActivityMutation(
		activityData || { name: '', type: ActivityType.QUESTION }
	)

	useEffect(() => {
		setCreatedActivityId(data?.id)
		if (data !== undefined && moduleId === undefined) {
			navigateHome?.()
		}
	}, [data])

	useEffect(() => {
		setActivityToAdd({ activities: [{ order: currentIndex!, activityId: createdActivityId! }] })
		if (createdActivityId !== undefined) mutateModuleActivity()
	}, [createdActivityId])

	useEffect(() => {
		if (moduleAddActivity !== undefined) {
			window.history.back()
		}
	}, [moduleAddActivity])

	const handleTitleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		setTitle(event.target.value)

		setEndOfContenteditable(document.getElementById('title') as HTMLInputElement)
	}

	const handleDescriptionChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		setDescription(event.target.innerText)

		setEndOfContenteditable(document.getElementById('description') as HTMLInputElement)
	}

	const addOption = () => {
		const optionsUpdated = [
			...options,
			{
				text: `${'Opção ' + (id + 1)}`,
				isCorrect: false
			}
		]

		setOptions(optionsUpdated)
	}

	const updateIsDisabledExternalModal = () => {
		if (files.length > 0) setisDisabled(false)
	}

	const openExternalContentModal: VoidFunction = () => {
		setModalContent?.(
			<ExternalContentModal
				updateDisabled={updateIsDisabledExternalModal}
				initialFiles={Object.assign(files)}
				resetSelect={reset}
				files={files}
				setFiles={setFiles}
				onClickCreate={onClickCreateModalExternal}
			/>
		)
		setVisibility?.(true)
	}

	const changeQuestionType = (event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => {
		const questionSelected = event.currentTarget.textContent

		if (questionSelected !== null) {
			const enumValue = questionTypeMapping[questionSelected]

			if (enumValue !== undefined) {
				if (question !== enumValue) {
					setOptions([initialOption])
					setisDisabled(true)
				}
				setCurrentQuestionType(enumValue)
			}
		} else {
			setCurrentQuestionType(currentQuestionType)
		}

		if (questionSelected === QuestionTypes.EXTERNAL_CONTENT) {
			const resetStatus = !reset
			setReset(resetStatus)
		}
		setFiles([])
	}

	const onClickCreateModalExternal = () => {
		setVisibility?.(false)
	}

	const handleTextOptionChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		if (event.currentTarget.type === 'checkbox') return

		setEndOfContenteditable(
			document.getElementById(
				'editable-option-' + event.currentTarget.id.replace(/\D+/g, '')
			) as HTMLInputElement
		)

		setOptions(
			options.map((option, index) => ({
				...option,
				text:
					index === Number(event.currentTarget.id.replace(/\D+/g, ''))
						? event.currentTarget.innerText
						: option.text
			}))
		)
	}

	const onCheckboxChangeCheckbox = (event: React.ChangeEvent<HTMLInputElement>) => {
		if (options[Number(event.target.name)].isCorrect === true) {
			options[Number(event.target.name)].isCorrect = false
			setisDisabled(true)
			return
		} else {
			const updatedOptions = options.map((item) => {
				return { ...item, isCorrect: false }
			})
			setisDisabled(false)

			updatedOptions[Number(event.target.name)].isCorrect = true
			setOptions(updatedOptions)
		}
	}

	const onClickCreate = () => {
		if (
			currentQuestionType === QuestionTypes.CHECKBOX ||
			currentQuestionType === QuestionTypes.MULTIPLE_CHOICE
		) {
			setActivityData({
				//description: description,
				name: question,
				type: ActivityType.QUESTION,
				questions: [
					{
						alternatives: options,
						text: question
					}
				]
			})

			mutate()
		} else {
			const formData = new FormData()
			files.forEach((file) => {
				formData.append('files', file)
			})

			formData.append('name', question)
			formData.append('type', ActivityType.MEDIA)

			setMediaPayload(formData)
		}

		setVisibility?.(false)
	}

	const handleQuestionChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		setEndOfContenteditable(document.getElementById('question') as HTMLInputElement)

		setQuestion(event.target.innerText)
	}

	const onClickUpdate = () => {
		updateMutate()
	}

	const onRadioChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		const updatedOptions = [...options]

		updatedOptions.findIndex(
			(option) => option.id === Number(event.currentTarget.id.replace(/\D+/g, ''))
		)

		updatedOptions[
			updatedOptions.findIndex(
				(option) => option.id === Number(event.currentTarget.id.replace(/\D+/g, ''))
			)
		].isCorrect =
			!updatedOptions[
				updatedOptions.findIndex(
					(option) => option.id === Number(event.currentTarget.id.replace(/\D+/g, ''))
				)
			].isCorrect

		if (options.some((option) => option.isCorrect)) {
			setisDisabled(false)
		} else setisDisabled(true)

		setOptions(updatedOptions)
	}

	const removeOption = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => {
		const updatedOptions = options.filter(
			(option) => option.id !== Number(event.currentTarget.id.replace(/\D+/g, ''))
		)

		setOptions(updatedOptions)
	}

	const handleRemoveFile = (index: number) => {
		setFiles((prevFiles) => prevFiles.filter((_, i) => i !== index))
	}

	const setEndOfContenteditable = (contentEditableElement: HTMLInputElement) => {
		if (contentEditableElement === null) return
		let range, selection
		if (document.createRange) {
			range = document.createRange()
			range.selectNodeContents(contentEditableElement)
			range.collapse(false)
			selection = window.getSelection()
			selection?.removeAllRanges()
			selection?.addRange(range)
		}
	}

	return (
		<ActivitiesPage>
			<div className='activity-info-container'>
				<EditableText className='name' id='title' text={title} onInput={handleTitleChange} />
				<EditableText
					onInput={handleDescriptionChange}
					className='description'
					id='description'
					text={description}
				/>
			</div>
			<div className='activity-content-container'>
				<Paper>
					<ActivityManagerViewer
						isPendingEdit={isUpdatePending}
						onClickUpdate={onClickUpdate}
						handleQuestionChange={handleQuestionChange}
						addOption={addOption}
						changeQuestionType={changeQuestionType}
						handleTextOptionChange={handleTextOptionChange}
						isDisabled={isDisabled}
						onCheckboxChangeCheckbox={onCheckboxChangeCheckbox}
						onClickCreate={onClickCreate}
						onRadioChange={onRadioChange}
						options={options}
						question={question}
						questionType={currentQuestionType}
						files={files}
						removeOption={removeOption}
						handleRemoveFile={handleRemoveFile}
						isPending={isPending}
						isEditing={isEditing}
						isPendingUploadMedia={isPendingUploadMedia}
						isPendingGetById={isPendingGetById}
						isCreatingByActivityList={isCreatingByActivityList}
						onClickPlusExternalContent={openExternalContentModal}
					></ActivityManagerViewer>
				</Paper>
			</div>
		</ActivitiesPage>
	)
}

export default OrganizationEditCreateActivities
