import React, { useEffect, useState } from 'react'
import './index.scss'
import { ReactComponent as EditPencil } from '../../../assets/icons/pecil.svg'
import { Card } from '../../../components/Card'
import { Button, ButtonProps } from '../../../components/Button'
import { useModal } from '../../../providers/Modal/ModalProvider'
import { useGetAllAreas } from '../../../services/core/areas/queries'
import { AreaDto } from '../../../dtos/AreaDto'
import AreaModal from './components/AreaModal'
import { Loader } from '../../../components/Loader'
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'

const OrganizationAreas: React.FC = () => {
	const { navigateCourses } = useNavigation()
	const { setModalContent, setVisibility } = useModal()
	const [areas, setArea] = useState<AreaDto[]>([])
	const { data, isLoading } = useGetAllAreas()

	useEffect(() => {
		if (data) setArea(data)
	}, [data])

	const handleCreate = () => {
		setModalContent?.(<AreaModal modalTitle='Criar Área' />)
		setVisibility?.(true)
	}

	const handleEdit = (area: AreaDto) => {
		setModalContent?.(<AreaModal modalTitle='Editando Área' area={area} isEdit />)
		setVisibility?.(true)
	}

	const renderCard = (item: AreaDto) => {
		const buttons: ButtonProps[] = [
			{
				variant: 'filled',
				color: 'primary',
				onClick: () => navigateCourses?.({ areaId: item.id }),
				children: (
					<div className='card-button-div'>
						<p className='card-button-text'>Entrar</p>
					</div>
				)
			},
			{
				variant: 'filled',
				color: 'gray',
				onClick: () => handleEdit(item),
				children: (
					<div className='card-button-div'>
						<EditPencil className='card-button-icon' />
						<p className='card-button-text'>Editar</p>
					</div>
				)
			}
		]
		return <Card title={item.name} imageUrl={item.imageUrl} buttons={buttons} />
	}

	return (
		<div className='area-container'>
			<div className='area-top'>
				<h1 className='area-title'>Áreas</h1>
				<p className='area-text'>
					Aqui você poderá criar e editar os níveis de acesso de cada colaborador, com seus
					conteúdos correspondentes.
				</p>
			</div>
			<div className='area-middle'>
				<div className='area-cards'>
					{isLoading ? (
						<div className='area-loader'>
							<Loader />
						</div>
					) : (
						areas.map((area) => renderCard(area))
					)}
				</div>
				<div className='area-bottom'>
					<div className='area-button'>
						<Button variant='filled' color='primary' size='big' onClick={handleCreate}>
							<p className='area-button-text-add'>Criar</p>
						</Button>
					</div>
				</div>
			</div>
		</div>
	)
}

export default OrganizationAreas
