/* eslint-disable @typescript-eslint/no-unused-vars */
import './index.scss'
import React, { useEffect, useState } from 'react'
import { Button } from '../../../../../components/Button'
import { useGetAllCourses } from '../../../../../services/core/courses/queries'
import { CourseListDto } from '../../../../../dtos/CourseDto'
import { useModal } from '../../../../../providers/Modal/ModalProvider'
import { ReactComponent as ListArrow } from '../../../../../assets/icons/list-arrow.svg'
import { Loader } from '../../../../../components/Loader'
import { useCourseAreaAssociation } from '../../../../../services/core/areas/mutations'
import DefaultModal from '../../../../../components/DefaultModal'

export interface CourseModalExistentProps {
	areaId: number | undefined
}

const CourseModalExistent: React.FC<CourseModalExistentProps> = (
	props: CourseModalExistentProps
) => {
	const [courses, setCourses] = useState<CourseListDto[]>([])
	const [selectedCourses, setSelectedCourses] = useState<number[]>([])
	const [isFull, setFull] = useState<boolean>(false)
	const [isDisabled, setDisabled] = useState<boolean>(true)
	const { setVisibility } = useModal()
	const { data, isLoading } = useGetAllCourses()
	const { mutate } = useCourseAreaAssociation({ courses: selectedCourses, areaId: props.areaId })

	const onClickCreate = () => {
		mutate()
		setVisibility?.(false)
	}

	const onSelectAll = () => {
		if (!data) return
		isFull
			? setSelectedCourses([])
			: setSelectedCourses(
					data?.map((v) => {
						return v.id
					})
				)
		isFull ? setDisabled(true) : setDisabled(false)
		setFull(!isFull)
	}

	const onCourseSelected = (value?: number) => {
		if (!value) return
		const oldValue = [...selectedCourses]
		if (selectedCourses.includes(value)) {
			setSelectedCourses(oldValue.filter((v) => v !== value))
			if (oldValue.filter((v) => v !== value).length === 0) setDisabled(true)
			return
		}
		setDisabled(false)
		setSelectedCourses((prev) => [...prev, value])
	}

	const isOptionSelected = (value?: number) => {
		if (value) return selectedCourses.includes(value)
		return false
	}

	useEffect(() => {
		if (data) setCourses(data)
	}, [data])

	return (
		<DefaultModal
			title='Lista de Cursos'
			subtitle='Escolha que curso adicionar entre os que já foram criados.'
			content={
				<div className='existent-middle'>
					<div className='existent-all' onClick={onSelectAll}>
						<ListArrow className='existent-all-icon' />
						<p className='existent-all-text'>Selecionar todos</p>
					</div>
					<div className='existent-select'>
						{isLoading ? (
							<Loader />
						) : (
							<ul className='select-list'>
								{courses.map((course, index) => (
									<li key={index} onClick={() => onCourseSelected(course.id)}>
										<input
											className='selected-checkbox'
											type='checkbox'
											checked={isOptionSelected(course.id)}
											readOnly
										/>
										{course.name}
									</li>
								))}
							</ul>
						)}
					</div>
				</div>
			}
			footer={
				<>
					<Button variant='outlined' color='black' onClick={() => setVisibility?.(false)}>
						<div className='modal-button-text'>Cancelar</div>
					</Button>
					<Button variant='filled' color='primary' disabled={isDisabled} onClick={onClickCreate}>
						<div className='modal-button-text'>Adicionar</div>
					</Button>
				</>
			}
		/>
	)
}

export default CourseModalExistent
