import './index.scss'
import CheckboxInput from '../../../../../../components/CheckboxInput'

export interface ModalQuestionTypes {
	questionName: InputInterface
	questionTree?: InputInterface[]
}

export interface InputInterface {
	isChecked: boolean
	label: string
	id?: number
}

export interface ModalContentProps {
	questionTypes: ModalQuestionTypes[]
	changeQuestionType: (questionChangedLabel: string) => void
}

export const ModalContent: React.FC<ModalContentProps> = (props: ModalContentProps) => {
	const { questionTypes, changeQuestionType } = props

	const onChangeCheckbox = async (event: React.ChangeEvent<HTMLInputElement>) => {
		const inputElement = event.target as HTMLInputElement
		const labelInput = inputElement.name
		changeQuestionType(labelInput)
	}

	return (
		<div className='container-input-div'>
			{questionTypes.map((question, index) => (
				<div className='types-div' key={index}>
					<CheckboxInput
						onChange={onChangeCheckbox}
						name={question.questionName.label}
						checked={question.questionName.isChecked}
						label={question.questionName.label}
						className='input questionInput'
					/>
					{question.questionTree !== undefined && question.questionTree.length !== 0 ? (
						<div className='question-tree-div' hidden={!question.questionName.isChecked}>
							{question.questionTree.map((questionChild, indexTree) => (
								<div key={indexTree + '-tree'} className='div-input-child'>
									<CheckboxInput
										onChange={onChangeCheckbox}
										name={questionChild.label}
										checked={questionChild.isChecked}
										label={questionChild.label}
										className='input-child questionChildInput'
									/>
								</div>
							))}
						</div>
					) : (
						''
					)}
				</div>
			))}
		</div>
	)
}
