import './index.scss'
import { ModalContent, ModalQuestionTypes } from './activity-modal-content'
import { useModal } from '../../../../../providers/Modal/ModalProvider'
import { ModalHeader, ParagraphInterface } from '../../../../../components/Header-Modal'
import { Button } from '../../../../../components/Button'
import { useState } from 'react'
import PAGES from '../../../../../utils/contants/pages'
import { useNavigate } from 'react-router-dom'

export interface ActivityModalProps {
	questions: ModalQuestionTypes[]
}

export const ActivityModal: React.FC<ActivityModalProps> = (props: ActivityModalProps) => {
	const [isDisabled, setIsDisabled] = useState<boolean>(true)
	const [questions, setQuestions] = useState<ModalQuestionTypes[]>(props.questions)
	const [questionSelected, setQuestionSelected] = useState<string>('Checkbox')

	const navigate = useNavigate()

	const updateQuestion = (checkboxChangedLabel: string) => {
		let checkChangeToDisableButton: boolean = false
		if (questions.findIndex((label) => checkboxChangedLabel === label.questionName.label) !== -1) {
			const changedQuestions = questions.map((question) => {
				if (question.questionName.label === checkboxChangedLabel) {
					question.questionName.isChecked = !question.questionName.isChecked
					if (!question.questionName.isChecked && question.questionTree !== undefined) {
						question.questionTree!.forEach((element) => {
							element.isChecked = false
						})
						checkChangeToDisableButton = true
					}
					if (question.questionName.isChecked === true && question.questionTree === undefined) {
						checkChangeToDisableButton = false
						setQuestionSelected(question.questionName.label)
					} else {
						checkChangeToDisableButton = true
					}
				} else {
					question.questionName.isChecked = false
					if (question.questionTree !== undefined) {
						question.questionTree.forEach((element) => (element.isChecked = false))
					}
				}
				return question
			})
			setQuestions(changedQuestions)
		} else {
			const changedQuestions = questions.map((question) => {
				if (question.questionTree !== undefined) {
					question.questionTree.forEach((currentQuestion) => {
						if (currentQuestion.label === checkboxChangedLabel) {
							currentQuestion.isChecked = !currentQuestion.isChecked
							if (currentQuestion.isChecked) {
								checkChangeToDisableButton = false
								setQuestionSelected(currentQuestion.label)
							} else checkChangeToDisableButton = true
						} else {
							currentQuestion.isChecked = false
						}
					})
				}
				return question
			})
			setQuestions(changedQuestions)
		}
		setIsDisabled(checkChangeToDisableButton)
	}

	const { setVisibility } = useModal()

	const headerTitle: ParagraphInterface = {
		text: 'Selecione o estilo de conteúdo',
		style: { fontWeight: 'bold', fontSize: '22px' }
	}
	const headerDescription = {
		text: 'Escolha qual o formato que mais encaixa com seu conteúdo!',
		style: { fontSize: '17px' }
	}
	const showDivider = true

	const onClickCreate = () => {
		setVisibility?.(false)
		navigate(PAGES.organizationEditCreateActivities, { state: { questionType: questionSelected } })
	}

	return (
		<div className='container-div'>
			<div className='header-modal'>
				<ModalHeader
					title={headerTitle}
					description={headerDescription}
					showDivider={showDivider}
				></ModalHeader>
			</div>
			<div className='content'>
				<ModalContent questionTypes={questions} changeQuestionType={updateQuestion}></ModalContent>
			</div>
			<div className='buttons-container'>
				<Button variant='outlined' color='black' onClick={() => setVisibility?.(false)}>
					<p className='button-text'>Cancelar</p>
				</Button>
				<Button variant='filled' color='black' disabled={isDisabled} onClick={onClickCreate}>
					<p className='button-text'>Criar</p>
				</Button>
			</div>
		</div>
	)
}

export default ActivityModal
