import './index.scss'
import { CardHome } from './components/CardHome'
import pin from '../../Organization/Home/images/pin.png'
import pencil from '../../Organization/Home/images/pencil.png'
import laptop from '../../Organization/Home/images/laptop.png'
import imagecard1 from '../../../assets/images/img-carousel-card1.png'
import imagecard2 from '../../../assets/images/img-carousel-card2.png'
import imagecard3 from '../../../assets/images/img-carousel-card3.png'
import Carousel from '../../../components/Carousel'
import { useModal } from '../../../providers/Modal/ModalProvider'
import ActivityModal from './components/ActivityModal'
import { useAuth } from '../../../providers/Auth/AuthProvider'
import { useState } from 'react'
import { ModalQuestionTypes } from './components/ActivityModal/activity-modal-content'

const questionsConst: ModalQuestionTypes[] = [
	{
		questionName: {
			label: 'Pergunta',
			isChecked: false
		},
		questionTree: [
			{
				label: 'Checkbox',
				isChecked: false
			},
			{
				label: 'Múltipla Escolha',
				isChecked: false
			}
		]
	},
	{
		questionName: {
			label: 'Conteúdo Externo',
			isChecked: false
		}
	}
]
import { useNavigation } from '../../../providers/Navigation/NavigationProvider'

const Home: React.FC = () => {
	const { setModalContent, setVisibility } = useModal()
	const [questions, setQuestions] = useState<ModalQuestionTypes[]>(questionsConst)

	const { user } = useAuth()
	const { navigateAdminDashboard, navigateAreas, navigateActivities } = useNavigation()
	const slides = [
		{
			title: 'Como é o Onboarding?',
			text: 'O onboarding não é apenas uma integração, mas sim a base para um relacionamento duradouro entre empresa e talentos. Seguir nosso método pode otimizar em 46% o tempo do RH com ações operacionais do onboarding.',
			image: imagecard1,
			variant: 'gradient-primary' as const
		},
		{
			title: 'Nossa Metodologia',
			text: 'As metodologias de onboarding são baseadas em learning science. Seguindo o indicado, diminua o early turnover e aumente a performance do seu novo talento!',
			image: imagecard2,
			variant: 'gradient-secondary' as const
		},
		{
			title: 'Organize sua equipe',
			text: 'Tenha acesso rápido a todos os seus colaboradores. Acompanhe o progresso deles e insira novos talentos na sua realidade!',
			image: imagecard3,
			variant: 'gradient-terciary' as const
		}
	]

	const onClickActivityButton = () => {
		questionsConst.forEach((question) => {
			question.questionName.isChecked = false
			if (question.questionTree !== undefined) {
				question.questionTree.forEach((childQuestion) => {
					childQuestion.isChecked = false
				})
			}
		})
		setQuestions(questionsConst)
		setModalContent?.(<ActivityModal questions={questions} />)
		setVisibility?.(true)
	}

	return (
		<div className='home-container'>
			<div className='home-content'>
				<h1 className='home-title'>
					{' '}
					Bem-Vindo, <span className='home-title-name'>{user?.friendlyName}</span>
				</h1>
				<div className='home-carousel'>
					<Carousel slides={slides} />
				</div>
				<div className='home-divider'>
					<div className='home-line primary'>
						<br />
					</div>
					<h2 className='home-subtitle'>Serviços</h2>
					<div className='home-line secondary'>
						<br />
					</div>
				</div>
				<div className='home-card-section'>
					<div className='home-card'>
						<CardHome
							color='terciary'
							title='Admin.'
							subTitle='configure seus colaboradores e administradores'
							buttonColor='secondary'
							icon={pin}
							size='big'
							onClick={() => navigateAdminDashboard?.()}
						/>
					</div>
					<div className='home-card'>
						<CardHome
							color='primary'
							title='Cursos'
							subTitle='acompanhe a trajetória dos seus colaboradores'
							buttonColor='secondary'
							icon={laptop}
							size='big'
							onClick={() => navigateAreas?.()}
						/>
					</div>
					<div className='home-card'>
						<CardHome
							onButtonClick={onClickActivityButton}
							color='secondary'
							title='Atividade'
							subTitle='crie atividades para seus colaboradores'
							buttonColor='primary'
							icon={pencil}
							size='big'
							onClick={() => navigateActivities?.()}
						/>
					</div>
				</div>
			</div>
		</div>
	)
}

export default Home
