import React from 'react'
import { Navigate } from 'react-router-dom'
import { useAuth } from '../providers/Auth/AuthProvider'
import PAGES from '../utils/contants/pages'
import { UserRole } from '../dtos/UserDto'

export interface ProtectedRouteProps {
	requireRoles: UserRole[]
	children: JSX.Element
}

export const ProtectedRoute = ({ children, requireRoles }: ProtectedRouteProps) => {
	const { isLogged, user } = useAuth()

	const canAccess = isLogged?.() && user && requireRoles.includes(user.role)

	if (!canAccess) return <Navigate to={PAGES.login} />
	return children
}
