import React from 'react'
import { BrowserRouter, Routes, Route } from 'react-router-dom'
import { routes } from './routes'
import Header from '../components/Header/'
import Blur from '../components/Blur'
import Modal from '../components/Modal'
import { ProtectedRoute } from './ProtectedRoute'
import { NavigationProvider } from '../providers/Navigation/NavigationProvider'

const Router: React.FC = () => {
	return (
		<BrowserRouter>
			<Routes>
				<>
					{routes.map((route, index) => {
						const element = route.requireAuth ? (
							<ProtectedRoute {...route}>{route.component}</ProtectedRoute>
						) : (
							route.component
						)
						return (
							<Route
								key={index}
								path={route.path}
								element={
									<NavigationProvider>
										{route.headerEnabled && <Header />}
										{element}
									</NavigationProvider>
								}
							/>
						)
					})}
				</>
			</Routes>
			<Blur />
			<Modal />
		</BrowserRouter>
	)
}

export default Router
