import { RouteProps } from 'react-router-dom'
import PAGES from '../utils/contants/pages'
import OrganizationHome from '../pages/Organization/Home'
import Login from '../pages/Login'
import CollaboratorHome from '../pages/Collaborator/Home'
import OrganizationModules from '../pages/Organization/Modules'
import { UserRole } from '../dtos/UserDto'
import OrganizationActivities from '../pages/Organization/Activities/List'
import OrganizationEditCreateActivities from '../pages/Organization/Activities/manage'
import Admin from '../pages/Organization/Admin'
import Area from '../pages/Organization/Area'
import OrganizationCourse from '../pages/Organization/Course'
import Home from '../pages/Home'
import CollaboratorCourse from '../pages/Collaborator/Course'
import CollaboratorModules from '../pages/Collaborator/Module'
import ColaboratorActivities from '../pages/Collaborator/Activities'

export interface RouteConfig extends Omit<RouteProps, 'component'> {
	component: JSX.Element
	requireAuth?: boolean
	requireRoles: UserRole[]
	headerEnabled: boolean
}

export const routes: RouteConfig[] = [
	{
		path: PAGES.home,
		component: <Home />,
		requireAuth: false,
		requireRoles: [],
		headerEnabled: true
	},
	{
		path: PAGES.collaboratorHome,
		component: <CollaboratorHome />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN, UserRole.COLLABORATOR],
		headerEnabled: true
	},
	{
		path: PAGES.organizationHome,
		component: <OrganizationHome />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.login,
		component: <Login />,
		requireAuth: false,
		requireRoles: [],
		headerEnabled: false
	},
	{
		path: PAGES.organizationModules(),
		component: <OrganizationModules />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.admin,
		component: <Admin />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.areas,
		component: <Area />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.organizationCourses,
		component: <OrganizationCourse />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.collaboratorCourses,
		component: <CollaboratorCourse />,
		requireAuth: true,
		requireRoles: [UserRole.COLLABORATOR],
		headerEnabled: true
	},
	{
		path: PAGES.collaboratorModules(),
		component: <CollaboratorModules />,
		requireAuth: true,
		requireRoles: [UserRole.COLLABORATOR],
		headerEnabled: true
	},
	{
		path: PAGES.organizationActivities(),
		component: <OrganizationActivities />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	},
	{
		path: PAGES.colaboratorActivities(),
		component: <ColaboratorActivities />,
		requireAuth: true,
		requireRoles: [UserRole.COLLABORATOR],
		headerEnabled: true
	},
	{
		path: PAGES.organizationEditCreateActivities,
		component: <OrganizationEditCreateActivities />,
		requireAuth: true,
		requireRoles: [UserRole.ADMIN],
		headerEnabled: true
	}
]
