import { useMutation } from '@tanstack/react-query'
import { ActivityDto, ActivityCreateDto, ActivityResponseDto } from '../../../dtos/ActivityDto'
import { activityApi } from '.'
import { queryClient } from '../../query-client'
import QUERY_KEYS from '../../../utils/contants/queries'

export const useActivityMutation = (payload: ActivityCreateDto) =>
	useMutation({
		mutationFn: () => activityApi.post('', payload).then((res) => res.data as ActivityDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.activity] })
	})

export const useActivityUpdateMutation = (payload: ActivityDto) =>
	useMutation({
		mutationFn: () =>
			activityApi.patch('', payload).then((res) => res.data.data as ActivityResponseDto),
		onSuccess: () =>
			queryClient.invalidateQueries({
				queryKey: [QUERY_KEYS.activityById + payload.id, QUERY_KEYS.activity]
			})
	})

export const useActivityMutationMedia = (payload: FormData) =>
	useMutation({
		mutationFn: () =>
			activityApi
				.post('', payload, {
					headers: {
						'content-type': 'multipart/form-data'
					}
				})
				.then((res) => res.data as ActivityResponseDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.activity] })
	})
