import { useMutation } from '@tanstack/react-query'
import { areasApi } from '.'
import { AreaDto } from '../../../dtos/AreaDto'
import { queryClient } from '../../query-client'
import QUERY_KEYS from '../../../utils/contants/queries'
import {
	CourseAreaAssociationDto,
	CourseAreaDto,
	CourseChangeOrderDto,
	CourseCreateDto,
	CourseDto
} from '../../../dtos/CourseDto'

export const useAreaCreateMutation = () =>
	useMutation({
		mutationFn: (payload: FormData) =>
			areasApi
				.post('', payload, {
					headers: {
						'Content-Type': 'multipart/form-data'
					}
				})
				.then((res) => res.data as AreaDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area] })
	})

export const useAreaUpdateMutation = () =>
	useMutation({
		mutationFn: (payload: FormData) =>
			areasApi
				.patch(`${payload.get('id')}`, payload, {
					headers: {
						'Content-Type': 'multipart/form-data'
					}
				})
				.then((res) => res.data as AreaDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area] })
	})

export const useAreaDeleteMutation = (areaId?: number) =>
	useMutation({
		mutationFn: () => areasApi.delete(`/${areaId}`).then((res) => res.data as AreaDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area] })
	})

export const useAreaCourseCreateMutation = (payload: CourseCreateDto) =>
	useMutation({
		mutationFn: () =>
			areasApi.post(`${payload.areaId}/courses`, payload).then((res) => res.data as CourseDto),
		onSuccess: () =>
			queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area, QUERY_KEYS.course] })
	})

export const useAreaCourseDeleteMutation = (courseId?: number, areaId?: number) =>
	useMutation({
		mutationFn: () =>
			areasApi.delete(`${areaId}/courses/${courseId}`).then((res) => res.data as CourseDto),
		onSuccess: () =>
			queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area, QUERY_KEYS.course] })
	})

export const useAreaCourseChangeOrderMutation = (
	areaId?: number,
	courses?: CourseChangeOrderDto[]
) =>
	useMutation({
		mutationFn: () =>
			areasApi.patch(`${areaId}/courses/order`, { courses }).then((res) => res.data as CourseDto[]),
		onSuccess: () =>
			queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.area, QUERY_KEYS.course] })
	})

export const useCourseAreaAssociation = (payload: CourseAreaAssociationDto) =>
	useMutation({
		mutationFn: () =>
			areasApi.post(`${payload.areaId}/courses`, payload).then((res) => res.data as CourseAreaDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.course] })
	})
