import { useQuery } from '@tanstack/react-query'
import QUERY_KEYS from '../../../utils/contants/queries'
import { courseApi } from '.'
import { ModuleDto } from '../../../dtos/ModuleDto'
import { CourseDto } from '../../../dtos/CourseDto'
import { ListWrapperDto } from '../../../dtos/PaginatedDto'
import { ActivityResponseDto } from '../../../dtos/ActivityDto'

export const useGetAllCourseModules = (courseId?: number) =>
	useQuery({
		enabled: !!courseId,
		queryKey: [QUERY_KEYS.course, QUERY_KEYS.module, courseId],
		queryFn: async () =>
			(await courseApi.get<ListWrapperDto<ModuleDto>>(`/${courseId}/modules`)).data.data
	})

export const useGetCourseModules = (courseId?: number, moduleId?: number) =>
	useQuery({
		enabled: !!courseId,
		queryKey: [QUERY_KEYS.course, QUERY_KEYS.module, courseId],
		queryFn: async () =>
			(await courseApi.get<ListWrapperDto<ModuleDto>>(`/${courseId}/modules/${moduleId}`)).data.data
	})

export const useGetAllCourseModulesActivities = (moduleId?: number) =>
	useQuery({
		enabled: !!moduleId,
		queryKey: [QUERY_KEYS.activity, QUERY_KEYS.module, QUERY_KEYS.activity + moduleId],
		queryFn: async () =>
			(await courseApi.get<ListWrapperDto<ActivityResponseDto>>(`/modules/${moduleId}/activities`))
				.data.data
	})

export const useGetAllCourses = () =>
	useQuery({
		queryKey: [QUERY_KEYS.course],
		queryFn: async () => (await courseApi.get<ListWrapperDto<CourseDto>>('')).data.data
	})

export const useGetAllCoursesWithArea = (areaId?: number) =>
	useQuery({
		enabled: !!areaId,
		queryKey: [QUERY_KEYS.areaCourse, areaId],
		queryFn: async () =>
			(await courseApi.get<ListWrapperDto<CourseDto>>(`${areaId ? '?areaId=' + areaId : ''}`)).data
				.data
	})
