import { useMutation } from '@tanstack/react-query'
import { userApi } from '.'
import {
	ResponseBatchUsers,
	UserCreateDto,
	UserDto,
	UserUpdateDto,
	UpdateProgressUser,
	UpdateProgressUserResponse
} from '../../../dtos/UserDto'
import { queryClient } from '../../query-client'
import QUERY_KEYS from '../../../utils/contants/queries'

export const useUserCreateMutation = (user: UserCreateDto) =>
	useMutation({
		mutationFn: () => userApi.post('', user).then((res) => res.data as UserDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.user] })
	})

export const useUserUpdateMutation = (payload: UserUpdateDto) =>
	useMutation({
		mutationFn: () => userApi.patch(`${payload.id}`, payload).then((res) => res.data as UserDto),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.user] })
	})

export const useUserDeleteMutation = (id?: number) =>
	useMutation({
		mutationFn: () => userApi.delete(`${id}`).then((res) => res.data as UserDto),
		onSuccess: () => queryClient.invalidateQueries({})
	})

export const useUserBatchCreateMutation = (users: UserCreateDto[]) =>
	useMutation({
		mutationFn: () => userApi.post('/batch', users).then((res) => res.data as ResponseBatchUsers),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.user] })
	})

export const useUserUpdateActivity = (payload: UpdateProgressUser, moduleActivityId?: number) =>
	useMutation({
		mutationFn: () =>
			userApi
				.patch(`/activities/${moduleActivityId}/progress`, payload)
				.then((res) => res.data as UpdateProgressUserResponse),
		onSuccess: () => queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.user] })
	})
